@@ -3,7 +3,7 @@ module Shoulda
     module ActionController
       # @private
       class RouteParams
-        PARAMS_TO_SYMBOLIZE = %i{ format }
+        PARAMS_TO_SYMBOLIZE = %i{format}.freeze
 
         def initialize(args)
           @args = args
@@ -27,7 +27,7 @@ module Shoulda
 
         def extract_params_from_string
           controller, action = args[0].split('#')
-          params = (args[1] || {}).merge(controller: controller, action: action)
+          params = (args[1] || {}).merge!(controller:, action:)
           normalize_values(params)
         end
 
