@@ -18,14 +18,14 @@ module Shoulda
       #
       #     # RSpec
       #     RSpec.describe UserProfile, type: :model do
-      #       it { should allow_value('http://foo.com').for(:website_url) }
-      #       it { should allow_value('http://bar.com').for(:website_url) }
+      #       it { should allow_value('https://foo.com').for(:website_url) }
+      #       it { should allow_value('https://bar.com').for(:website_url) }
       #     end
       #
       #     # Minitest (Shoulda)
       #     class UserProfileTest < ActiveSupport::TestCase
-      #       should allow_value('http://foo.com').for(:website_url)
-      #       should allow_value('http://bar.com').for(:website_url)
+      #       should allow_value('https://foo.com').for(:website_url)
+      #       should allow_value('https://bar.com').for(:website_url)
       #     end
       #
       # You can also test multiple values in one go, if you like. In the
@@ -36,7 +36,7 @@ module Shoulda
       #     # RSpec
       #     RSpec.describe UserProfile, type: :model do
       #       it do
-      #         should allow_values('http://foo.com', 'http://bar.com').
+      #         should allow_values('https://foo.com', 'https://bar.com').
       #           for(:website_url)
       #       end
       #
@@ -48,7 +48,7 @@ module Shoulda
       #
       #     # Minitest (Shoulda)
       #     class UserProfileTest < ActiveSupport::TestCase
-      #       should allow_values('http://foo.com', 'http://bar.com/baz').
+      #       should allow_values('https://foo.com', 'https://bar.com/baz').
       #         for(:website_url)
       #
       #       should_not allow_values('foo', 'buz').
@@ -169,6 +169,36 @@ module Shoulda
       #         on(:create)
       #     end
       #
+      # ##### against
+      #
+      # Use `against` if the validation is on an attribute
+      # other than the attribute being validated:
+      #
+      #     class UserProfile
+      #       include ActiveModel::Model
+      #       attr_accessor :website_url
+      #
+      #       alias_attribute :url, :website_url
+      #
+      #       validates_format_of :url, with: URI.regexp
+      #     end
+      #
+      #     # RSpec
+      #     RSpec.describe UserProfile, type: :model do
+      #       it do
+      #         should allow_value('https://foo.com').
+      #           for(:website_url).
+      #           against(:url)
+      #       end
+      #     end
+      #
+      #     # Minitest (Shoulda)
+      #     class UserProfileTest < ActiveSupport::TestCase
+      #       should allow_value('https://foo.com').
+      #         for(:website_url).
+      #         against(:url)
+      #     end
+      #
       # ##### with_message
       #
       # Use `with_message` if you are using a custom validation message.
@@ -313,7 +343,7 @@ module Shoulda
           :attribute_to_check_message_against,
           :attribute_to_set,
           :context,
-          :instance
+          :instance,
         )
 
         attr_writer(
@@ -349,6 +379,12 @@ module Shoulda
           self
         end
 
+        def against(attribute)
+          @attribute_to_check_message_against = attribute if attribute.present?
+
+          self
+        end
+
         def with_message(message, given_options = {})
           if message.present?
             @expects_custom_validation_message = true
@@ -402,6 +438,10 @@ module Shoulda
           @result.nil?
         end
 
+        def has_any_errors?
+          validator.record.errors.any?
+        end
+
         def failure_message
           attribute_setter = result.attribute_setter
 
@@ -423,55 +463,56 @@ module Shoulda
           end
 
           if include_attribute_changed_value_message?
-            message << "\n\n" + attribute_changed_value_message.call
+            message << "\n\n#{attribute_changed_value_message.call}"
           end
 
           Shoulda::Matchers.word_wrap(message)
         end
 
-        def failure_message_when_negated
+        def failure_message_when_negated # rubocop:disable Metrics/MethodLength
           attribute_setter = result.attribute_setter
 
           if attribute_setter.unsuccessfully_checked?
             message = attribute_setter.failure_message
           else
             validator = result.validator
-            message = failure_message_preface.call + ' invalid'
+            message = "#{failure_message_preface.call} invalid"
 
             if validator.type_of_message_matched?
               if validator.has_messages?
                 message << ' and to'
 
-                if validator.captured_validation_exception?
+                if validator.captured_validation_exception? # rubocop:disable Metrics/BlockNesting
                   message << ' raise a validation exception with message'
                 else
                   message << ' produce'
 
-                  if expected_message.is_a?(Regexp)
-                    message << ' a'
-                  else
-                    message << ' the'
-                  end
+                  message <<
+                    if expected_message.is_a?(Regexp) # rubocop:disable Metrics/BlockNesting
+                      ' a'
+                    else
+                      ' the'
+                    end
 
                   message << ' validation error'
                 end
 
-                if expected_message.is_a?(Regexp)
+                if expected_message.is_a?(Regexp) # rubocop:disable Metrics/BlockNesting
                   message << ' matching '
                   message << Shoulda::Matchers::Util.inspect_value(
-                    expected_message
+                    expected_message,
                   )
                 else
                   message << " #{expected_message.inspect}"
                 end
 
-                unless validator.captured_validation_exception?
+                unless validator.captured_validation_exception? # rubocop:disable Metrics/BlockNesting
                   message << " on :#{attribute_to_check_message_against}"
                 end
 
                 message << '. The record was indeed invalid, but'
 
-                if validator.captured_validation_exception?
+                if validator.captured_validation_exception? # rubocop:disable Metrics/BlockNesting
                   message << ' the exception message was '
                   message << validator.validation_exception_message.inspect
                   message << ' instead.'
@@ -479,6 +520,11 @@ module Shoulda
                   message << " it produced these validation errors instead:\n\n"
                   message << validator.all_formatted_validation_error_messages
                 end
+              elsif validator.has_any_errors?
+                message << ", placing a validation error on :#{attribute_setter.attribute_name}"
+                message << '. The Example was invalid,'
+                message << " but it had errors involving other attributes:\n\n"
+                message << validator.all_formatted_validation_error_messages
               else
                 message << ', but it was valid instead.'
               end
@@ -492,7 +538,7 @@ module Shoulda
           end
 
           if include_attribute_changed_value_message?
-            message << "\n\n" + attribute_changed_value_message.call
+            message << "\n\n#{attribute_changed_value_message.call}"
           end
 
           Shoulda::Matchers.word_wrap(message)
@@ -531,7 +577,8 @@ module Shoulda
 
         def run(strategy)
           attribute_setters_for_values_to_preset.first_failing ||
-            attribute_setters_and_validators_for_values_to_set.public_send(strategy)
+            attribute_setters_and_validators_for_values_to_set.
+              public_send(strategy)
         end
 
         def failure_message_preface
@@ -539,7 +586,7 @@ module Shoulda
         end
 
         def default_failure_message_preface
-          ''.tap do |preface|
+          String.new.tap do |preface|
             if descriptions_for_preset_values.any?
               preface << 'After setting '
               preface << descriptions_for_preset_values.to_sentence
@@ -597,14 +644,14 @@ pass, or do something else entirely.
           @_attribute_setters_and_validators_for_values_to_set ||=
             AttributeSettersAndValidators.new(
               self,
-              values_to_set.map { |value| [attribute_to_set, value] }
+              values_to_set.map { |value| [attribute_to_set, value] },
             )
         end
 
         def inspected_values_to_set
           Shoulda::Matchers::Util.inspect_values(values_to_set).to_sentence(
-            two_words_connector: " or ",
-            last_word_connector: ", or "
+            two_words_connector: ' or ',
+            last_word_connector: ', or ',
           )
         end
 
@@ -619,18 +666,18 @@ pass, or do something else entirely.
         def default_attribute_message
           default_error_message(
             options[:expected_message],
-            default_attribute_message_values
+            default_attribute_message_values,
           )
         end
 
         def default_attribute_message_values
           defaults = {
-            model_name: model_name,
-            instance: instance,
+            model_name:,
+            instance:,
             attribute: attribute_to_check_message_against,
           }
 
-          defaults.merge(options[:expected_message_values])
+          defaults.merge!(options[:expected_message_values])
         end
 
         def model_name
@@ -639,7 +686,7 @@ pass, or do something else entirely.
 
         def human_attribute_name
           instance.class.human_attribute_name(
-            attribute_to_check_message_against
+            attribute_to_check_message_against,
           )
         end
       end
