@@ -8,7 +8,7 @@ module Shoulda
         end
 
         def format_validation_errors(errors)
-          list_items = errors.keys.map do |attribute|
+          list_items = errors.to_hash.keys.map do |attribute|
             messages = errors[attribute]
             "* #{attribute}: #{messages}"
           end
@@ -26,7 +26,7 @@ module Shoulda
             attribute.to_sym,
             type,
             model_name,
-            options
+            options,
           )
         end
       end
