@@ -3,12 +3,15 @@ require 'date'
 
 module Shoulda
   module Matchers
+    # @private
+    class ExampleClass; end
+
     module ActiveModel
       # The `validate_inclusion_of` matcher tests usage of the
       # `validates_inclusion_of` validation, asserting that an attribute can
-      # take a whitelist of values and cannot take values outside of this list.
+      # take a allowlist of values and cannot take values outside of this list.
       #
-      # If your whitelist is an array of values, use `in_array`:
+      # If your allowlist is an array of values, use `in_array`:
       #
       #     class Issue
       #       include ActiveModel::Model
@@ -32,7 +35,7 @@ module Shoulda
       #         in_array(['open', 'resolved', 'unresolved'])
       #     end
       #
-      # If your whitelist is a range of values, use `in_range`:
+      # If your allowlist is a range of values, use `in_range`:
       #
       #     class Issue
       #       include ActiveModel::Model
@@ -43,12 +46,12 @@ module Shoulda
       #
       #     # RSpec
       #     RSpec.describe Issue, type: :model do
-      #       it { should validate_inclusion_of(:state).in_range(1..5) }
+      #       it { should validate_inclusion_of(:priority).in_range(1..5) }
       #     end
       #
       #     # Minitest (Shoulda)
       #     class IssueTest < ActiveSupport::TestCase
-      #       should validate_inclusion_of(:state).in_range(1..5)
+      #       should validate_inclusion_of(:priority).in_range(1..5)
       #     end
       #
       # #### Caveats
@@ -268,20 +271,20 @@ module Shoulda
 
       # @private
       class ValidateInclusionOfMatcher < ValidationMatcher
-        BLANK_VALUES = ['', ' ', "\n", "\r", "\t", "\f"]
-        ARBITRARY_OUTSIDE_STRING = 'shoulda-matchers test string'
+        BLANK_VALUES = ['', ' ', "\n", "\r", "\t", "\f"].freeze
+        ARBITRARY_OUTSIDE_STRING = Shoulda::Matchers::ExampleClass.name
         ARBITRARY_OUTSIDE_INTEGER = 123456789
         ARBITRARY_OUTSIDE_DECIMAL = BigDecimal('0.123456789')
         ARBITRARY_OUTSIDE_DATE = Date.jd(9999999)
         ARBITRARY_OUTSIDE_DATETIME = DateTime.jd(9999999)
         ARBITRARY_OUTSIDE_TIME = Time.at(9999999999)
-        BOOLEAN_ALLOWS_BOOLEAN_MESSAGE = <<EOT
+        BOOLEAN_ALLOWS_BOOLEAN_MESSAGE = <<EOT.freeze
 You are using `validate_inclusion_of` to assert that a boolean column allows
 boolean values and disallows non-boolean ones. Be aware that it is not possible
 to fully test this, as boolean columns will automatically convert non-boolean
 values to boolean ones. Hence, you should consider removing this test.
 EOT
-        BOOLEAN_ALLOWS_NIL_MESSAGE = <<EOT
+        BOOLEAN_ALLOWS_NIL_MESSAGE = <<EOT.freeze
 You are using `validate_inclusion_of` to assert that a boolean column allows nil.
 Be aware that it is not possible to fully test this, as anything other than
 true, false or nil will be converted to false. Hence, you should consider
@@ -306,20 +309,11 @@ EOT
 
         def in_range(range)
           @range = range
-          @minimum = range.first
-          @maximum = range.max
+          @minimum = minimum_range_value
+          @maximum = maximum_range_value
           self
         end
 
-        def allow_blank
-          @options[:allow_blank] = true
-          self
-        end
-
-        def expects_to_allow_blank?
-          @options[:allow_blank]
-        end
-
         def allow_nil
           @options[:allow_nil] = true
           self
@@ -363,11 +357,12 @@ EOT
           else
             description = "validate that :#{@attribute}"
 
-            if @array.many?
-              description << " is either #{inspected_array}"
-            else
-              description << " is #{inspected_array}"
-            end
+            description <<
+              if @array.length > 1
+                " is either #{inspected_array}"
+              else
+                " is #{inspected_array}"
+              end
 
             description
           end
@@ -405,6 +400,18 @@ EOT
 
         private
 
+        def minimum_range_value
+          @range.begin
+        end
+
+        def maximum_range_value
+          if @range.exclude_end?
+            @range.end ? (@range.end - 1) : nil
+          else
+            @range.end
+          end
+        end
+
         def matches_for_range?
           disallows_lower_value &&
             allows_minimum_value &&
@@ -423,14 +430,14 @@ EOT
           allows_all_values_in_array? &&
             disallows_all_values_outside_of_array? &&
             allows_nil_value? &&
-            allows_blank_value?
+            allow_blank_matches?
         end
 
         def does_not_match_for_array?
           disallows_any_values_in_array? ||
             allows_any_value_outside_of_array? ||
             disallows_nil_value? ||
-            disallows_blank_value?
+            allow_blank_does_not_match?
         end
 
         def allows_lower_value
@@ -446,27 +453,27 @@ EOT
         end
 
         def allows_minimum_value
-          allows_value_of(@minimum, @low_message)
+          @minimum.nil? || allows_value_of(@minimum, @low_message)
         end
 
         def disallows_minimum_value
-          disallows_value_of(@minimum, @low_message)
+          @minimum.nil? || disallows_value_of(@minimum, @low_message)
         end
 
         def allows_maximum_value
-          allows_value_of(@maximum, @high_message)
+          @maximum.nil? || allows_value_of(@maximum, @high_message)
         end
 
         def disallows_maximum_value
-          disallows_value_of(@maximum, @high_message)
+          @maximum.nil? || disallows_value_of(@maximum, @high_message)
         end
 
         def allows_higher_value
-          allows_value_of(@maximum + 1, @high_message)
+          @maximum.nil? || allows_value_of(@maximum + 1, @high_message)
         end
 
         def disallows_higher_value
-          disallows_value_of(@maximum + 1, @high_message)
+          @maximum.nil? || disallows_value_of(@maximum + 1, @high_message)
         end
 
         def allows_all_values_in_array?
@@ -554,10 +561,10 @@ EOT
           values = []
 
           values << case @array
-            when [true]  then false
-            when [false] then true
-            else              raise CouldNotDetermineValueOutsideOfArray
-          end
+                    when [true]  then false
+                    when [false] then true
+                    else              raise CouldNotDetermineValueOutsideOfArray
+                    end
 
           if attribute_allows_nil?
             values << nil
@@ -590,21 +597,21 @@ EOT
 
         def column_type_to_attribute_type(type)
           case type
-            when :float then :integer
-            when :timestamp then :datetime
-            else type
+          when :float then :integer
+          when :timestamp then :datetime
+          else type
           end
         end
 
         def value_to_attribute_type(value)
           case value
-            when true, false then :boolean
-            when BigDecimal then :decimal
-            when Integer then :integer
-            when Date then :date
-            when DateTime then :datetime
-            when Time then :time
-            else :unknown
+          when true, false then :boolean
+          when BigDecimal then :decimal
+          when Integer then :integer
+          when Date then :date
+          when DateTime then :datetime
+          when Time then :time
+          else :unknown
           end
         end
 
@@ -616,20 +623,10 @@ EOT
           @options[:allow_nil] && disallows_value_of(nil)
         end
 
-        def allows_blank_value?
-          @options[:allow_blank] != true ||
-            BLANK_VALUES.all? { |value| allows_value_of(value) }
-        end
-
-        def disallows_blank_value?
-          @options[:allow_blank] &&
-            BLANK_VALUES.any? { |value| disallows_value_of(value) }
-        end
-
         def inspected_array
           Shoulda::Matchers::Util.inspect_values(@array).to_sentence(
-            two_words_connector: " or ",
-            last_word_connector: ", or "
+            two_words_connector: ' or ',
+            last_word_connector: ', or ',
           )
         end
       end
