@@ -20,7 +20,7 @@ module Shoulda
 
         def debug(&block)
           if debugging_enabled?
-            puts block.call
+            puts block.call # rubocop:disable Rails/Output
           end
         end
       end
