@@ -24,10 +24,10 @@ module Shoulda
 
         def method_missing(method_name, *args, &block)
           call = MethodCall.new(
-            method_name: method_name,
-            args: args,
-            block: block,
-            caller: ::Kernel.caller
+            method_name:,
+            args:,
+            block:,
+            caller: ::Kernel.caller,
           )
           calls << call
           (calls_by_method_name[method_name] ||= []) << call
