@@ -1,8 +1,7 @@
-PROJECT_ROOT = File.expand_path('../..', __FILE__)
+PROJECT_ROOT = File.expand_path('..', __dir__)
 $LOAD_PATH << File.join(PROJECT_ROOT, 'lib')
 
 require 'pry'
-require 'pry-byebug'
 
 require 'rspec'
 
