@@ -22,13 +22,14 @@ module AcceptanceTests
 
       def failure_message
         message = "Expected output to indicate that #{some_tests_were_run}.\n" +
-          "Expected output: #{expected_output}\n"
+                  "Expected output: #{expected_output}\n"
 
-        if actual_output.empty?
-          message << 'Actual output: (empty)'
-        else
-          message << "Actual output:\n#{actual_output}"
-        end
+        message <<
+          if actual_output.empty?
+            'Actual output: (empty)'
+          else
+            "Actual output:\n#{actual_output}"
+          end
 
         message
       end
@@ -48,7 +49,7 @@ module AcceptanceTests
       end
 
       def some_tests_were_run
-        pluralize(number, 'test was', 'tests were') + ' run'
+        "#{pluralize(number, 'test was', 'tests were')} run"
       end
     end
   end
