@@ -29,7 +29,7 @@ EOT
     end
 
     def latest_appraisal
-      available_appraisals.sort.last
+      available_appraisals.max
     end
 
     def available_appraisals
@@ -40,7 +40,7 @@ EOT
 
     def current_appraisal
       if appraisal_in_use?
-        File.basename(path, ".gemfile")
+        File.basename(path, '.gemfile')
       end
     end
 
