@@ -1,6 +1,6 @@
 module Kernel
-  # #capture, #silence_stream, and #silence_stderr are deprecated after Rails
-  # 4.2 and will be removed in 5.0, so just override them completely here
+  # #capture, #silence_stream, and #silence_stderr were removed in rails 5.0,
+  # but we keep it them here
 
   if method_defined?(:capture)
     undef_method :capture
@@ -9,14 +9,14 @@ module Kernel
   def capture(stream)
     stream = stream.to_s
     captured_stream = Tempfile.new(stream)
-    stream_io = eval("$#{stream}")
+    stream_io = eval("$#{stream}", binding, __FILE__, __LINE__) # rubocop:disable Security/Eval
     origin_stream = stream_io.dup
     stream_io.reopen(captured_stream)
 
     yield
 
     stream_io.rewind
-    return captured_stream.read
+    captured_stream.read
   ensure
     captured_stream.unlink
     stream_io.reopen(origin_stream)
@@ -41,6 +41,6 @@ module Kernel
   end
 
   def silence_stderr
-    silence_stream(STDERR) { yield }
+    silence_stream($stderr) { yield if block_given? }
   end
 end
