@@ -11,12 +11,12 @@ module UnitTests
       Tests::Version.new(Rails::VERSION::STRING)
     end
 
-    def rails_lt_5?
-      rails_version < 5
+    def rails_oldest_version_supported
+      7.1
     end
 
-    def rails_5_x?
-      rails_version =~ '~> 5.0'
+    def rails_gt_8_0?
+      rails_version >= '8.0'
     end
   end
 end
