@@ -18,9 +18,9 @@ module UnitTests
 
       def initialize(args)
         @arguments = CreateModelArguments::Basic.wrap(
-          args.merge(
-            model_creation_strategy: UnitTests::ModelCreationStrategies::ActiveModel
-          )
+          args.merge!(
+            model_creation_strategy: UnitTests::ModelCreationStrategies::ActiveModel,
+          ),
         )
         @model_creator = Basic.new(arguments)
       end
