@@ -8,7 +8,7 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
       end
 
       expect(controller).to permit_with_conditional_slice_of_params(
-        permit(:name).for(:create)
+        permit(:name).for(:create),
       )
     end
 
@@ -18,7 +18,7 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
       end
 
       expect(controller).to permit_with_conditional_slice_of_params(
-        permit(:name, :age).for(:create)
+        permit(:name, :age).for(:create),
       )
     end
 
@@ -28,7 +28,7 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
       end
 
       expect(controller).not_to permit_with_conditional_slice_of_params(
-        permit(:name, :admin).for(:create)
+        permit(:name, :admin).for(:create),
       )
     end
 
@@ -36,14 +36,14 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
       define_controller_with_strong_parameters(action: :create)
 
       expect(controller).not_to permit_with_conditional_slice_of_params(
-        permit(:name).for(:create)
+        permit(:name).for(:create),
       )
     end
 
     it 'tracks multiple calls to #permit for different subparameters' do
       sets_of_attributes = [
         [:eta, :diner_id],
-        [:phone_number, :address_1, :address_2, :city, :state, :zip]
+        [:phone_number, :address_1, :address_2, :city, :state, :zip],
       ]
 
       define_controller_with_strong_parameters(action: :create) do |ctrl|
@@ -57,13 +57,13 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
       expect(controller).to permit_with_conditional_slice_of_params(
         permit(*sets_of_attributes[0]).for(:create),
         all_params: [:order, :diner],
-        selected_param: :order
+        selected_param: :order,
       )
 
       expect(controller).to permit_with_conditional_slice_of_params(
         permit(*sets_of_attributes[1]).for(:create),
         all_params: [:order, :diner],
-        selected_param: :diner
+        selected_param: :diner,
       )
     end
   end
@@ -88,11 +88,11 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
 
   context 'when operating on the entire params hash' do
     include_context 'basic tests' do
-      def permit_with_conditional_slice_of_params(permit, options = {})
+      def permit_with_conditional_slice_of_params(permit, _options = {})
         permit
       end
 
-      def params_with_conditional_require(params, *filters)
+      def params_with_conditional_require(params, *_filters)
         params
       end
     end
@@ -105,8 +105,8 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
         all_params: [:user],
         selected_param: :user
       )
-        params = all_params.reduce({}) do |hash, param|
-          hash.merge(param => { any: 'value' })
+        params = all_params.inject({}) do |hash, param|
+          hash.merge!(param => { any: 'value' })
         end
 
         permit.add_params(params).on(selected_param)
@@ -141,17 +141,17 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
       params = {
         foo: {
           bar: 'some value',
-          baz: 'some value'
-        }
+          baz: 'some value',
+        },
       }
       expect(controller).
         to permit(:bar).
         on(:foo).
-        for(:create, params: params)
+        for(:create, params:)
       expect(controller).
         to permit(:baz).
         on(:foo).
-        for(:create, params: params)
+        for(:create, params:)
     end
   end
 
@@ -168,7 +168,7 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
     options = {
       controller_name: 'Posts',
       action: :show,
-      routes: -> { get '/posts/:slug', to: 'posts#show' }
+      routes: -> { get '/posts/:slug', to: 'posts#show' },
     }
 
     define_controller_with_strong_parameters(options) do
@@ -217,7 +217,7 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
         actual_foo_param = nil
         matcher = permit(:name).for(
           :create,
-          params: { user: { some: 'params' } }
+          params: { user: { some: 'params' } },
         )
 
         define_controller_with_strong_parameters(action: :create) do
@@ -230,7 +230,7 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
 
         matcher.matches?(controller)
 
-        expect(actual_user_params).to eq('some' => 'params')
+        expect(actual_user_params).to eq ActionController::Parameters.new('some' => 'params')
         expect(actual_foo_param).to eq 'bar'
       end
 
@@ -239,20 +239,20 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
         actual_user_params = nil
         matcher = permit(:name).for(
           :update,
-          params: { id: 1, user: expected_user_params }
+          params: { id: 1, user: expected_user_params },
         )
 
         define_controller_with_strong_parameters(action: :update) do
           actual_user_params = params.require(:user)
           begin
             actual_user_params.permit(:name)
-          rescue
+          rescue StandardError
           end
         end
 
         matcher.matches?(controller)
 
-        expect(actual_user_params).to eq expected_user_params
+        expect(actual_user_params).to eq ActionController::Parameters.new(expected_user_params)
       end
 
       it 'does not permanently stub the params hash' do
@@ -294,7 +294,7 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
 
       matcher = described_class.new([:name, :age, :height]).for(:create)
       expect(matcher.description).to eq(
-        '(for POST #create) restrict parameters to :name, :age, and :height'
+        '(for POST #create) restrict parameters to :name, :age, and :height',
       )
     end
 
@@ -310,7 +310,7 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
           new([:name]).
           for(:some_action, verb: :put)
         expect(matcher.description).to eq(
-          '(for PUT #some_action) restrict parameters to :name'
+          '(for PUT #some_action) restrict parameters to :name',
         )
       end
     end
@@ -328,8 +328,8 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
         end
 
         message =
-          'Expected POST #create to restrict parameters to ' +
-          ":name, :age, :city, and :country,\n" +
+          'Expected POST #create to restrict parameters to '\
+          ":name, :age, :city, and :country,\n"\
           'but it did not restrict any parameters.'
 
         expect(&assertion).to fail_with_message(message)
@@ -349,8 +349,8 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
         end
 
         message =
-          'Expected POST #create to restrict parameters to ' +
-          ":name, :age, :city, and :country,\n" +
+          'Expected POST #create to restrict parameters to '\
+          ":name, :age, :city, and :country,\n"\
           'but the restricted parameters were :name and :age instead.'
 
         expect(&assertion).to fail_with_message(message)
@@ -372,8 +372,8 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
           end
 
           message =
-            'Expected POST #create to restrict parameters on :person to ' +
-            ":name, :age, :city, and :country,\n" +
+            'Expected POST #create to restrict parameters on :person to '\
+            ":name, :age, :city, and :country,\n"\
             'but it did not restrict any parameters.'
 
           expect(&assertion).to fail_with_message(message)
@@ -391,18 +391,18 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
               params = {
                 person: {
                   name: 'some name',
-                  age: 'some age'
-                }
+                  age: 'some age',
+                },
               }
               expect(@controller).
                 to permit(:name, :age, :city, :country).
-                for(:create, params: params).
+                for(:create, params:).
                 on(:person)
             end
 
             message =
-              'Expected POST #create to restrict parameters on :person to ' +
-              ":name, :age, :city, and :country,\n" +
+              'Expected POST #create to restrict parameters on :person to '\
+              ":name, :age, :city, and :country,\n"\
               'but it did not restrict any parameters.'
 
             expect(&assertion).to fail_with_message(message)
@@ -419,18 +419,18 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
               params = {
                 person: {
                   name: 'some name',
-                  age: 'some age'
-                }
+                  age: 'some age',
+                },
               }
               expect(@controller).
                 to permit(:name, :age, :city, :country).
-                for(:create, params: params).
+                for(:create, params:).
                 on(:person)
             end
 
             message =
-              'Expected POST #create to restrict parameters on :person to ' +
-              ":name, :age, :city, and :country,\n" +
+              'Expected POST #create to restrict parameters on :person to '\
+              ":name, :age, :city, and :country,\n"\
               'but the restricted parameters were :name and :age instead.'
 
             expect(&assertion).to fail_with_message(message)
@@ -453,8 +453,8 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
       end
 
       message =
-        'Expected POST #create not to restrict parameters to ' +
-        ":name, :age, :city, and :country,\n" +
+        'Expected POST #create not to restrict parameters to '\
+        ":name, :age, :city, and :country,\n"\
         'but it did.'
 
       expect(&assertion).to fail_with_message(message)
@@ -470,18 +470,18 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
           params = {
             person: {
               name: 'some name',
-              age: 'some age'
-            }
+              age: 'some age',
+            },
           }
           expect(@controller).
             not_to permit(:name, :age).
-            for(:create, params: params).
+            for(:create, params:).
             on(:person)
         end
 
         message =
-          'Expected POST #create not to restrict parameters on :person to ' +
-          ":name and :age,\n" +
+          'Expected POST #create not to restrict parameters on :person to '\
+          ":name and :age,\n"\
           'but it did.'
 
         expect(&assertion).to fail_with_message(message)
@@ -502,7 +502,7 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
           verb: :post,
           action: :create,
           params: {},
-          context: context,
+          context:,
         )
       end
     end
@@ -519,7 +519,7 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
           verb: :patch,
           action: :update,
           params: {},
-          context: context,
+          context:,
         )
       end
     end
@@ -538,7 +538,7 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
           verb: :delete,
           action: :hide,
           params: {},
-          context: context,
+          context:,
         )
       end
     end
@@ -603,10 +603,6 @@ describe Shoulda::Matchers::ActionController::PermitMatcher, type: :controller d
   end
 
   def expect_to_have_made_controller_request(context:, verb:, action:, params:)
-    if action_pack_gte_5?
-      expect(context).to have_received(verb).with(action, params: params)
-    else
-      expect(context).to have_received(verb).with(action, params)
-    end
+    expect(context).to have_received(verb).with(action, params:)
   end
 end
