@@ -9,12 +9,12 @@ describe Shoulda::Matchers::ActiveModel, type: :model do
 end
 
 describe Shoulda::Matchers::ActiveModel::AllowValueMatcher, type: :model do
-  context "#description" do
+  context '#description' do
     it 'describes itself with two values' do
       matcher = allow_value('foo', 'bar').for(:baz)
 
       expect(matcher.description).to eq(
-        'allow :baz to be ‹"foo"› or ‹"bar"›'
+        'allow :baz to be ‹"foo"› or ‹"bar"›',
       )
     end
 
@@ -22,7 +22,7 @@ describe Shoulda::Matchers::ActiveModel::AllowValueMatcher, type: :model do
       matcher = allow_value('foo', 'bar', 'qux').for(:baz)
 
       expect(matcher.description).to eq(
-        'allow :baz to be ‹"foo"›, ‹"bar"›, or ‹"qux"›'
+        'allow :baz to be ‹"foo"›, ‹"bar"›, or ‹"qux"›',
       )
     end
 
@@ -32,14 +32,10 @@ describe Shoulda::Matchers::ActiveModel::AllowValueMatcher, type: :model do
       expect(matcher.description).to eq 'allow :baz to be ‹"foo"›'
     end
 
-    if active_model_3_2?
-      it 'describes itself with a strict validation' do
-        strict_matcher = allow_value('xyz').for(:attr).strict
+    it 'truncates the description when long' do
+      matcher = allow_value('A' * 10000).for(:baz)
 
-        expect(strict_matcher.description).to eq(
-          'allow :attr to be ‹"xyz"›, raising a validation exception on failure'
-        )
-      end
+      expect(matcher.description).to eq "allow :baz to be ‹\"#{'A' * 499}...›"
     end
   end
 
@@ -294,12 +290,12 @@ errors instead:
         it 'accepts' do
           options = {
             attribute_name: :attr,
-            attribute_type: :string
+            attribute_type: :string,
           }
 
           record = record_with_custom_validation(options) do
-            if self.attr == 'xyz'
-              self.errors.add :attr, :greater_than, count: 2
+            if attr == 'xyz'
+              errors.add :attr, :greater_than, count: 2
             end
           end
 
@@ -314,12 +310,12 @@ errors instead:
         it 'rejects with an appropriate failure message' do
           options = {
             attribute_name: :attr,
-            attribute_type: :string
+            attribute_type: :string,
           }
 
           record = record_with_custom_validation(options) do
-            if self.attr == 'xyz'
-              self.errors.add :attr, "some other error"
+            if attr == 'xyz'
+              errors.add :attr, 'some other error'
             end
           end
 
@@ -347,6 +343,40 @@ errors instead:
 
   context 'when the attribute being validated is different than the attribute that receives the validation error' do
     include UnitTests::AllowValueMatcherHelpers
+    context 'when no validation message was provided directly' do
+      context 'when asserting the negative' do
+        it 'rejects with an appropriate failure message' do
+          builder = builder_for_record_with_unrelated_error
+          assertion = lambda do
+            expect(builder.record).
+              not_to allow_value(builder.valid_value).
+              for(builder.attribute_to_validate)
+          end
+
+          message = <<-MESSAGE
+After setting :attribute_to_validate to ‹"some value"›, the matcher
+expected the Example to be invalid, placing a validation error on
+:attribute_to_validate. The Example was invalid, but it had errors
+involving other attributes:
+
+* attribute_that_receives_error: ["some message"]
+          MESSAGE
+          expect(&assertion).to fail_with_message(message)
+        end
+      end
+    end
+
+    context 'when the attribute that receives the validation error is provided' do
+      context 'given a valid value' do
+        it 'accepts' do
+          builder = builder_for_record_with_different_error_attribute
+          expect(builder.record).
+            to allow_value(builder.valid_value).
+            for(builder.attribute_to_validate).
+            against(builder.attribute_that_receives_error)
+        end
+      end
+    end
 
     context 'when the validation error message was provided directly' do
       context 'given a valid value' do
@@ -357,7 +387,7 @@ errors instead:
             for(builder.attribute_to_validate).
             with_message(
               builder.message,
-              against: builder.attribute_that_receives_error
+              against: builder.attribute_that_receives_error,
             )
         end
       end
@@ -372,14 +402,14 @@ errors instead:
             for(builder.attribute_to_validate).
             with_message(
               builder.message,
-              against: builder.attribute_that_receives_error
+              against: builder.attribute_that_receives_error,
             )
         end
 
         context 'if the messages do not match' do
           it 'technically accepts' do
             builder = builder_for_record_with_different_error_attribute(
-              message: "a different error"
+              message: 'a different error',
             )
             invalid_value = "#{builder.valid_value} (invalid)"
 
@@ -388,8 +418,8 @@ errors instead:
                 not_to allow_value(invalid_value).
                 for(builder.attribute_to_validate).
                 with_message(
-                  "some error",
-                  against: builder.attribute_that_receives_error
+                  'some error',
+                  against: builder.attribute_that_receives_error,
                 )
             end
 
@@ -416,7 +446,7 @@ indeed invalid, but it produced these validation errors instead:
           for(builder.attribute_to_validate).
           with_message(
             builder.validation_message_key,
-            against: builder.attribute_that_receives_error
+            against: builder.attribute_that_receives_error,
           )
       end
 
@@ -428,26 +458,26 @@ indeed invalid, but it produced these validation errors instead:
           for(builder.attribute_to_validate).
           with_message(
             builder.validation_message_key,
-            against: builder.attribute_that_receives_error
+            against: builder.attribute_that_receives_error,
           )
       end
     end
   end
 
-  context "an attribute with a context-dependent validation" do
-    context "without the validation context" do
-      it "allows a bad value" do
-        expect(validating_format(with: /abc/, on: :customisable)).to allow_value("xyz").for(:attr)
+  context 'an attribute with a context-dependent validation' do
+    context 'without the validation context' do
+      it 'allows a bad value' do
+        expect(validating_format(with: /abc/, on: :customisable)).to allow_value('xyz').for(:attr)
       end
     end
 
-    context "with the validation context" do
-      it "allows a good value" do
-        expect(validating_format(with: /abc/, on: :customisable)).to allow_value("abcde").for(:attr).on(:customisable)
+    context 'with the validation context' do
+      it 'allows a good value' do
+        expect(validating_format(with: /abc/, on: :customisable)).to allow_value('abcde').for(:attr).on(:customisable)
       end
 
-      it "rejects a bad value" do
-        expect(validating_format(with: /abc/, on: :customisable)).not_to allow_value("xyz").for(:attr).on(:customisable)
+      it 'rejects a bad value' do
+        expect(validating_format(with: /abc/, on: :customisable)).not_to allow_value('xyz').for(:attr).on(:customisable)
       end
     end
   end
@@ -457,8 +487,11 @@ indeed invalid, but it produced these validation errors instead:
       define_model :example, attr: :string do
         validates_presence_of     :attr
         validates_length_of       :attr, within: 1..5
-        validates_numericality_of :attr, greater_than_or_equal_to: 1,
-          less_than_or_equal_to: 50000
+        validates_numericality_of(
+          :attr,
+          greater_than_or_equal_to: 1,
+          less_than_or_equal_to: 50000,
+        )
       end.new
     end
 
@@ -484,7 +517,7 @@ indeed invalid, but it produced these validation errors instead:
         ignoring_interference_by_writer
     end
 
-    it "does not match given good values along with bad values" do
+    it 'does not match given good values along with bad values' do
       message = <<-MESSAGE.strip_heredoc
 After setting :attr to ‹"12345"›, the matcher expected the Example to be
 invalid, but it was valid instead.
@@ -497,7 +530,7 @@ invalid, but it was valid instead.
       expect(&assertion).to fail_with_message(message)
     end
 
-    it "does not match given bad values along with good values" do
+    it 'does not match given bad values along with good values' do
       message = <<-MESSAGE.strip_heredoc
 After setting :attr to ‹"12345"›, the matcher expected the Example to be
 invalid, but it was valid instead.
@@ -528,45 +561,6 @@ invalid, but it was valid instead.
     end
   end
 
-  if active_model_3_2?
-    context 'an attribute with a strict format validation' do
-      context 'when qualified with strict' do
-        it 'rejects a bad value, providing the correct failure message' do
-          message = <<-MESSAGE.strip_heredoc
-After setting :attr to ‹"xyz"›, the matcher expected the Example to be
-valid, but it was invalid instead, raising a validation exception with
-the message "Attr is invalid".
-          MESSAGE
-
-          assertion = lambda do
-            expect(validating_format(with: /abc/, strict: true)).
-              to allow_value('xyz').for(:attr).strict
-          end
-
-          expect(&assertion).to fail_with_message(message)
-        end
-
-        context 'qualified with a custom message' do
-          it 'rejects a bad value when the failure messages do not match' do
-            message = <<-MESSAGE.strip_heredoc
-After setting :attr to ‹"xyz"›, the matcher expected the Example to be
-invalid and to raise a validation exception with message matching
-‹/abc/›. The record was indeed invalid, but the exception message was
-"Attr is invalid" instead.
-            MESSAGE
-
-            assertion = lambda do
-              expect(validating_format(with: /abc/, strict: true)).
-                not_to allow_value('xyz').for(:attr).with_message(/abc/).strict
-            end
-
-            expect(&assertion).to fail_with_message(message)
-          end
-        end
-      end
-    end
-  end
-
   context 'when the attribute interferes with attempts to be set' do
     context 'when the attribute cannot be changed from nil to non-nil' do
       context 'and the record remains valid' do
@@ -688,7 +682,7 @@ something else entirely.
           model = define_active_model_class 'Example', accessors: [:name] do
             validates_format_of :name, with: /another name/
 
-            def name=(value)
+            def name=(_value)
               super('constant name')
             end
           end
@@ -735,7 +729,7 @@ that attribute does not exist.
 
         expect(&assertion).to raise_error(
           described_class::AttributeDoesNotExistError,
-          message
+          message,
         )
       end
     end
@@ -755,7 +749,7 @@ that attribute does not exist.
 
         expect(&assertion).to raise_error(
           described_class::AttributeDoesNotExistError,
-          message
+          message,
         )
       end
     end
@@ -778,11 +772,11 @@ that attribute does not exist.
           message = <<-MESSAGE.rstrip
 The matcher attempted to set :nonexistent on the Example to "some
 value", but that attribute does not exist.
-        MESSAGE
+          MESSAGE
 
           expect(&assertion).to raise_error(
             described_class::AttributeDoesNotExistError,
-            message
+            message,
           )
         end
       end
@@ -804,11 +798,11 @@ value", but that attribute does not exist.
           message = <<-MESSAGE.rstrip
 The matcher attempted to set :nonexistent on the Example to "some
 value", but that attribute does not exist.
-        MESSAGE
+          MESSAGE
 
           expect(&assertion).to raise_error(
             described_class::AttributeDoesNotExistError,
-            message
+            message,
           )
         end
       end
@@ -818,8 +812,13 @@ value", but that attribute does not exist.
   context 'given an ActiveRecord model' do
     context 'where the attribute under test is an enum and the given value is a value in that enum' do
       it 'accepts' do
+        enum_definition = if rails_gt_8_0?
+                            'enum :status, { pending: 1, shipped: 2, delivered: 3 }'
+                          else
+                            'enum status: { pending: 1, shipped: 2, delivered: 3 }'
+                          end
         model = define_model('Shipment', status: :integer) do
-          enum status: { pending: 1, shipped: 2, delivered: 3 }
+          class_eval(enum_definition)
         end
 
         expect(model.new).to allow_value(1).for(:status)
