@@ -21,7 +21,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       def build_object(**options, &block)
         build_object_with_generic_attribute(
-          options.merge(column_type: :integer, value: 1),
+          **options.merge(column_type: :integer, value: 1),
           &block
         )
       end
@@ -45,7 +45,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       def build_object(**options, &block)
         build_object_with_generic_attribute(
-          options.merge(
+          **options.merge(
             column_type: :integer,
             column_options: { limit: 2 },
             value: 1,
@@ -71,7 +71,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       def build_object(**options, &block)
         build_object_with_generic_attribute(
-          options.merge(column_type: :float, value: 1.0),
+          **options.merge(column_type: :float, value: 1.0),
           &block
         )
       end
@@ -99,7 +99,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       def build_object(**options, &block)
         build_object_with_generic_attribute(
-          options.merge(column_type: :decimal, value: BigDecimal('1.0')),
+          **options.merge(column_type: :decimal, value: BigDecimal('1.0')),
           &block
         )
       end
@@ -130,7 +130,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       define_method :build_object do |options = {}, &block|
         build_object_with_generic_attribute(
-          options.merge(column_type: :date, value: today),
+          **options.merge(column_type: :date, value: today),
           &block
         )
       end
@@ -145,7 +145,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
     end
 
     context 'against a datetime attribute' do
-      now = DateTime.now
+      now = DateTime.new(2022, 1, 1)
 
       define_method(:now) { now }
 
@@ -158,7 +158,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       define_method :build_object do |options = {}, &block|
         build_object_with_generic_attribute(
-          options.merge(column_type: :datetime, value: now),
+          **options.merge(column_type: :datetime, value: now),
           &block
         )
       end
@@ -178,7 +178,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
       define_method(:default_time) { default_time }
 
       it_behaves_like 'it supports in_array',
-        possible_values: (1..3).map { |hour| default_time.change(hour: hour) }
+        possible_values: (1..3).map { |hour| default_time.change(hour:) }
 
       it_behaves_like 'it supports in_range', possible_values: (
         default_time.change(hour: 1)..default_time.change(hour: 3)
@@ -186,7 +186,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       define_method :build_object do |options = {}, &block|
         build_object_with_generic_attribute(
-          options.merge(column_type: :time, value: default_time),
+          **options.merge(column_type: :time, value: default_time),
           &block
         )
       end
@@ -207,7 +207,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       def build_object(**options, &block)
         build_object_with_generic_attribute(
-          options.merge(column_type: :string),
+          **options.merge(column_type: :string),
           &block
         )
       end
@@ -454,7 +454,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
     it 'matches given a subset of the valid values' do
       builder = build_object_allowing(possible_values)
-      expect_to_match_on_values(builder, possible_values[1..-1])
+      expect_to_match_on_values(builder, possible_values[1..])
     end
 
     if zero
@@ -475,9 +475,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
     if reserved_outside_value
       it 'raises an error when valid and given value is our test outside value' do
-        # rubocop:disable Metrics/LineLength
         error_class = Shoulda::Matchers::ActiveModel::CouldNotDetermineValueOutsideOfArray
-        # rubocop:enable Metrics/LineLength
         builder = build_object_allowing([reserved_outside_value])
 
         expect { expect_to_match_on_values(builder, [reserved_outside_value]) }.
@@ -521,51 +519,6 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
     it_behaves_like 'it supports with_message', valid_values: possible_values
 
-    if active_model_3_2?
-      context '+ strict' do
-        context 'when the validation specifies strict' do
-          it 'matches when the given values match the valid values' do
-            builder = build_object_allowing(
-              possible_values,
-              validation_options: { strict: true },
-            )
-
-            # rubocop:disable Style/SymbolProc
-            expect_to_match_on_values(builder, possible_values) do |matcher|
-              matcher.strict
-            end
-            # rubocop:enable Style/SymbolProc
-          end
-
-          it 'does not match when the given values do not match the valid values' do
-            builder = build_object_allowing(
-              possible_values,
-              validation_options: { strict: true },
-            )
-
-            values = add_outside_value_to(possible_values)
-            # rubocop:disable Style/SymbolProc
-            expect_not_to_match_on_values(builder, values) do |matcher|
-              matcher.strict
-            end
-            # rubocop:enable Style/SymbolProc
-          end
-        end
-
-        context 'when the validation does not specify strict' do
-          it 'does not match' do
-            builder = build_object_allowing(possible_values)
-
-            # rubocop:disable Style/SymbolProc
-            expect_not_to_match_on_values(builder, possible_values) do |matcher|
-              matcher.strict
-            end
-            # rubocop:enable Style/SymbolProc
-          end
-        end
-      end
-    end
-
     def expect_to_match_on_values(builder, values, &block)
       expect_to_match_in_array(builder, values, &block)
     end
@@ -619,6 +572,22 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
       expect_to_match_on_values(builder, possible_values)
     end
 
+    it 'matches given a beginless range that covers the possible values' do
+      builder = build_object_allowing(possible_values)
+      expect_to_match_on_values(
+        builder,
+        Range.new(nil, possible_values.last),
+      )
+    end
+
+    it 'matches given a endless range that covers the possible values' do
+      builder = build_object_allowing(possible_values)
+      expect_to_match_on_values(
+        builder,
+        Range.new(possible_values.first, nil),
+      )
+    end
+
     it 'does not match given a range whose start value falls outside valid range' do
       builder = build_object_allowing(possible_values)
       expect_not_to_match_on_values(
@@ -677,51 +646,6 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
     it_behaves_like 'it supports with_message', valid_values: possible_values
 
-    if active_model_3_2?
-      context '+ strict' do
-        context 'when the validation specifies strict' do
-          it 'matches when the given range matches the range in the validation' do
-            builder = build_object_allowing(
-              possible_values,
-              validation_options: { strict: true },
-            )
-
-            # rubocop:disable Style/SymbolProc
-            expect_to_match_on_values(builder, possible_values) do |matcher|
-              matcher.strict
-            end
-            # rubocop:enable Style/SymbolProc
-          end
-
-          it 'matches when the given range does not match the range in the validation' do
-            builder = build_object_allowing(
-              possible_values,
-              validation_options: { strict: true },
-            )
-
-            range = Range.new(possible_values.first, possible_values.last + 1)
-            # rubocop:disable Style/SymbolProc
-            expect_not_to_match_on_values(builder, range) do |matcher|
-              matcher.strict
-            end
-            # rubocop:enable Style/SymbolProc
-          end
-        end
-
-        context 'when the validation does not specify strict' do
-          it 'does not match' do
-            builder = build_object_allowing(possible_values)
-
-            # rubocop:disable Style/SymbolProc
-            expect_not_to_match_on_values(builder, possible_values) do |matcher|
-              matcher.strict
-            end
-            # rubocop:enable Style/SymbolProc
-          end
-        end
-      end
-    end
-
     def expect_to_match_on_values(builder, range, &block)
       expect_to_match_in_range(builder, range, &block)
     end
@@ -770,7 +694,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
           valid_values = booleans
           builder = build_object_allowing(valid_values)
           message =
-            'You are using `validate_inclusion_of` to assert that a boolean ' +
+            'You are using `validate_inclusion_of` to assert that a boolean '\
             'column allows boolean values and disallows non-boolean ones'
 
           stderr = capture(:stderr) do
@@ -787,8 +711,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
     include_context 'for a generic attribute'
 
     context 'against a timestamp column' do
-      now = DateTime.now
-
+      now = DateTime.new(2022, 1, 1)
       define_method(:now) { now }
 
       it_behaves_like 'it supports in_array',
@@ -800,7 +723,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       define_method :build_object do |options = {}, &block|
         build_object_with_generic_attribute(
-          options.merge(column_type: :timestamp, value: now),
+          **options.merge(column_type: :timestamp, value: now),
           &block
         )
       end
@@ -831,7 +754,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
             valid_values = [nil]
             builder = build_object_allowing(valid_values)
             message =
-              'You are using `validate_inclusion_of` to assert that a ' +
+              'You are using `validate_inclusion_of` to assert that a '\
               'boolean column allows nil'
 
             stderr = capture(:stderr) do
@@ -844,7 +767,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
         def build_object(**options, &block)
           super(
-            options.merge(column_options: { null: true }, value: true),
+            **options.merge(column_options: { null: true }, value: true),
             &block
           )
         end
@@ -857,10 +780,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
           it 'raises a specific error' do
             valid_values = [nil]
             builder = build_object_allowing(valid_values)
-            # rubocop:disable Metrics/LineLength
             error_class = Shoulda::Matchers::ActiveModel::NonNullableBooleanError
-            # rubocop:enable Metrics/LineLength
-
             expect {
               expect_to_match_in_array(builder, valid_values)
             }.to raise_error(error_class)
@@ -868,13 +788,13 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
         end
 
         def build_object(**options, &block)
-          super(options.merge(column_options: { null: false }), &block)
+          super(**options.merge(column_options: { null: false }), &block)
         end
       end
 
       def build_object(**options, &block)
         build_object_with_generic_attribute(
-          options.merge(column_type: :boolean),
+          **options.merge(column_type: :boolean),
           &block
         )
       end
@@ -892,6 +812,41 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
     def validation_matcher_scenario_args
       super.deep_merge(model_creator: :active_record)
     end
+
+    context 'against a polymorphic association' do
+      it 'matches when the subject configures validate_inclusion_of' do
+        define_model(:issue, severity_id: :integer, severity_type: :string) do
+          belongs_to :severity, polymorphic: true, optional: true
+          validates_inclusion_of :severity_type, in: %w(Low Medium High)
+        end
+        define_model(:high)
+        define_model(:medium)
+        define_model(:low)
+
+        expect { validate_inclusion_of(:severity_type).in_array(%w(Low Medium High)) }.to match_against(Issue.new)
+      end
+
+      it 'does not match when subject does not set validate_inclusion_of' do
+        define_model(:issue, severity_id: :integer, severity_type: :string) do
+          belongs_to :severity, polymorphic: true, optional: true
+        end
+        define_model(:high)
+        define_model(:medium)
+        define_model(:low)
+
+        expected_message = <<-MESSAGE.strip
+Expected Issue to validate that :severity_type is either ‹"Low"›,
+‹"Medium"›, or ‹"High"›, but this could not be proved.
+  After setting :severity_type to ‹"Shoulda::Matchers::ExampleClass"›,
+  the matcher expected the Issue to be invalid, but it was valid
+  instead.
+        MESSAGE
+
+        expect { validate_inclusion_of(:severity_type).in_array(%w(Low Medium High)) }.
+          not_to match_against(Issue.new).
+          and_fail_with(expected_message)
+      end
+    end
   end
 
   context 'for a plain Ruby attribute' do
@@ -901,7 +856,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
       include_context 'against a boolean attribute for true and false'
 
       def build_object(**options, &block)
-        build_object_with_generic_attribute(options.merge(value: true), &block)
+        build_object_with_generic_attribute(**options.merge(value: true), &block)
       end
     end
 
@@ -909,7 +864,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
       include_context 'against a boolean attribute for true and false'
 
       def build_object(**options, &block)
-        build_object_with_generic_attribute(options.merge(value: false), &block)
+        build_object_with_generic_attribute(**options.merge(value: false), &block)
       end
     end
 
@@ -987,9 +942,9 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
     **other_options
   )
     model = define_model_validating_inclusion(
-      model_name: model_name,
-      attribute_name: attribute_name,
-      validation_options: validation_options,
+      model_name:,
+      attribute_name:,
+      validation_options:,
       **other_options,
     )
 
@@ -1010,12 +965,12 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
   )
     column_options = { type: column_type, options: column_options }
     model_options = {
-      model_name: model_name,
-      attribute_name: attribute_name,
-      column_options: column_options,
+      model_name:,
+      attribute_name:,
+      column_options:,
     }.compact
 
-    define_simple_model(model_options) do |model|
+    define_simple_model(**model_options) do |model|
       if validation_options
         model.validates_inclusion_of(attribute_name, validation_options)
       end
