@@ -2,7 +2,7 @@ require 'unit_spec_helper'
 
 describe Shoulda::Matchers::ActiveModel::ValidateNumericalityOfMatcher, type: :model do
   class << self
-    def all_qualifiers
+    def all_qualifiers # rubocop:disable Metrics/MethodLength
       [
         {
           category: :comparison,
@@ -39,6 +39,13 @@ describe Shoulda::Matchers::ActiveModel::ValidateNumericalityOfMatcher, type: :m
           validation_name: :equal_to,
           validation_value: 1,
         },
+        {
+          category: :comparison,
+          name: :is_other_than,
+          argument: 1,
+          validation_name: :other_than,
+          validation_value: 1,
+        },
         {
           category: :cardinality,
           name: :odd,
@@ -60,28 +67,36 @@ describe Shoulda::Matchers::ActiveModel::ValidateNumericalityOfMatcher, type: :m
           name: :on,
           argument: :customizable,
           validation_name: :on,
-          validation_value: :customizable
-        }
+          validation_value: :customizable,
+        },
+        {
+          category: :range,
+          name: :is_in,
+          argument: 1..10,
+          validation_name: :in,
+          validation_value: 1..10,
+          rails_version: 7.0,
+        },
       ]
     end
 
     def qualifiers_under(category)
-      all_qualifiers.select do |qualifier|
+      all_available_qualifiers.select do |qualifier|
         qualifier[:category] == category
       end
     end
 
     def mutually_exclusive_qualifiers
-      qualifiers_under(:cardinality) + qualifiers_under(:comparison)
+      qualifiers_under(:cardinality) + qualifiers_under(:comparison) + qualifiers_under(:range)
     end
 
     def non_mutually_exclusive_qualifiers
-      all_qualifiers - mutually_exclusive_qualifiers
+      all_available_qualifiers - mutually_exclusive_qualifiers
     end
 
-    def validations_by_qualifier
-      all_qualifiers.each_with_object({}) do |qualifier, hash|
-        hash[qualifier[:name]] = qualifier[:validation_name]
+    def all_available_qualifiers
+      all_qualifiers.filter do |qualifier|
+        rails_version >= qualifier.fetch(:rails_version, rails_oldest_version_supported)
       end
     end
 
@@ -137,7 +152,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateNumericalityOfMatcher, type: :m
             model_name: 'Example',
             attribute_name: :attr,
             changing_values_with: :numeric_value,
-            expected_message: <<-MESSAGE.strip
+            expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr looks like a number, but this
 could not be proved.
   After setting :attr to ‹"abcd"› -- which was read back as ‹"1"› -- the
@@ -149,8 +164,8 @@ could not be proved.
   attribute, then you may need to change it to make this test pass, or
   do something else entirely.
             MESSAGE
-          }
-        }
+          },
+        },
       )
 
       context 'when the attribute is a virtual attribute in an ActiveRecord model' do
@@ -247,7 +262,7 @@ could not be proved.
             model_name: 'Example',
             attribute_name: :attr,
             changing_values_with: :next_value_or_non_numeric_value,
-            expected_message: <<-MESSAGE.strip
+            expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr looks like a number as long as
 it is not nil, but this could not be proved.
   In checking that Example allows :attr to be ‹nil›, after setting :attr
@@ -263,8 +278,8 @@ it is not nil, but this could not be proved.
   attribute, then you may need to change it to make this test pass, or
   do something else entirely.
             MESSAGE
-          }
-        }
+          },
+        },
       ) do
         def validation_matcher_scenario_args
           super.deep_merge(validation_options: { allow_nil: true })
@@ -316,10 +331,11 @@ it is not nil, but this could not be proved.
         expect(&assertion).to fail_with_message(<<~MESSAGE)
 Expected Example not to validate that :attr looks like an integer, but
 this could not be proved.
-  After setting :attr to ‹"0.1"›, the matcher expected the Example to be
-  valid, but it was invalid instead, producing these validation errors:
+  After setting :attr to ‹"abcd"›, the matcher expected the Example to
+  be valid, but it was invalid instead, producing these validation
+  errors:
 
-  * attr: ["must be an integer"]
+  * attr: ["is not a number"]
         MESSAGE
       end
 
@@ -333,10 +349,10 @@ this could not be proved.
             model_name: 'Example',
             attribute_name: :attr,
             changing_values_with: :numeric_value,
-            expected_message: <<-MESSAGE.strip
+            expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr looks like an integer, but this
 could not be proved.
-  After setting :attr to ‹"0.1"› -- which was read back as ‹"1"› -- the
+  After setting :attr to ‹"abcd"› -- which was read back as ‹"1"› -- the
   matcher expected the Example to be invalid, but it was valid instead.
 
   As indicated in the message above, :attr seems to be changing certain
@@ -345,8 +361,8 @@ could not be proved.
   attribute, then you may need to change it to make this test pass, or
   do something else entirely.
             MESSAGE
-          }
-        }
+          },
+        },
       ) do
         def validation_matcher_scenario_args
           super.deep_merge(validation_options: { only_integer: true })
@@ -395,10 +411,11 @@ could not be proved.
         expect(&assertion).to fail_with_message(<<~MESSAGE)
 Expected Example not to validate that :attr looks like an odd number,
 but this could not be proved.
-  After setting :attr to ‹"2"›, the matcher expected the Example to be
-  valid, but it was invalid instead, producing these validation errors:
+  After setting :attr to ‹"abcd"›, the matcher expected the Example to
+  be valid, but it was invalid instead, producing these validation
+  errors:
 
-  * attr: ["must be odd"]
+  * attr: ["is not a number"]
         MESSAGE
       end
 
@@ -412,7 +429,7 @@ but this could not be proved.
             model_name: 'Example',
             attribute_name: :attr,
             changing_values_with: :next_value,
-            expected_message: <<-MESSAGE.strip
+            expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr looks like an odd number, but
 this could not be proved.
   After setting :attr to ‹"2"› -- which was read back as ‹"3"› -- the
@@ -424,8 +441,8 @@ this could not be proved.
   attribute, then you may need to change it to make this test pass, or
   do something else entirely.
             MESSAGE
-          }
-        }
+          },
+        },
       ) do
         def validation_matcher_scenario_args
           super.deep_merge(validation_options: { odd: true })
@@ -439,7 +456,7 @@ this could not be proved.
       context 'when the attribute is a virtual attribute in ActiveRecord model' do
         it 'accepts' do
           record = build_record_validating_numericality_of_virtual_attribute(
-            odd: true
+            odd: true,
           )
           expect(record).to validate_numericality.odd
         end
@@ -449,7 +466,7 @@ this could not be proved.
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :integer,
-            odd: true
+            odd: true,
           )
 
           expect(record).to validate_numericality.odd
@@ -460,7 +477,7 @@ this could not be proved.
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :float,
-            odd: true
+            odd: true,
           )
 
           expect(record).to validate_numericality.odd
@@ -516,10 +533,11 @@ this could not be proved.
         expect(&assertion).to fail_with_message(<<~MESSAGE)
 Expected Example not to validate that :attr looks like an even number,
 but this could not be proved.
-  After setting :attr to ‹"1"›, the matcher expected the Example to be
-  valid, but it was invalid instead, producing these validation errors:
+  After setting :attr to ‹"abcd"›, the matcher expected the Example to
+  be valid, but it was invalid instead, producing these validation
+  errors:
 
-  * attr: ["must be even"]
+  * attr: ["is not a number"]
         MESSAGE
       end
 
@@ -533,7 +551,7 @@ but this could not be proved.
             model_name: 'Example',
             attribute_name: :attr,
             changing_values_with: :next_value,
-            expected_message: <<-MESSAGE.strip
+            expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr looks like an even number, but
 this could not be proved.
   After setting :attr to ‹"1"› -- which was read back as ‹"2"› -- the
@@ -545,8 +563,8 @@ this could not be proved.
   attribute, then you may need to change it to make this test pass, or
   do something else entirely.
             MESSAGE
-          }
-        }
+          },
+        },
       ) do
         def validation_matcher_scenario_args
           super.deep_merge(validation_options: { even: true })
@@ -570,7 +588,7 @@ this could not be proved.
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :integer,
-            even: true
+            even: true,
           )
 
           expect(record).to validate_numericality.even
@@ -581,7 +599,7 @@ this could not be proved.
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :float,
-            even: true
+            even: true,
           )
 
           expect(record).to validate_numericality.even
@@ -653,7 +671,7 @@ than or equal to 18, but this could not be proved.
             model_name: 'Example',
             attribute_name: :attr,
             changing_values_with: :next_value,
-            expected_message: <<-MESSAGE.strip
+            expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr looks like a number less than or
 equal to 18, but this could not be proved.
   After setting :attr to ‹"18"› -- which was read back as ‹"19"› -- the
@@ -668,12 +686,12 @@ equal to 18, but this could not be proved.
   attribute, then you may need to change it to make this test pass, or
   do something else entirely.
             MESSAGE
-          }
-        }
+          },
+        },
       ) do
         def validation_matcher_scenario_args
           super.deep_merge(
-            validation_options: { less_than_or_equal_to: 18 }
+            validation_options: { less_than_or_equal_to: 18 },
           )
         end
 
@@ -695,7 +713,7 @@ equal to 18, but this could not be proved.
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :integer,
-            less_than_or_equal_to: 18
+            less_than_or_equal_to: 18,
           )
 
           expect(record).to validate_numericality.is_less_than_or_equal_to(18)
@@ -706,7 +724,7 @@ equal to 18, but this could not be proved.
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :float,
-            less_than_or_equal_to: 18
+            less_than_or_equal_to: 18,
           )
 
           expect(record).to validate_numericality.is_less_than_or_equal_to(18)
@@ -779,7 +797,7 @@ than 18, but this could not be proved.
             model_name: 'Example',
             attribute_name: :attr,
             changing_values_with: :next_value,
-            expected_message: <<-MESSAGE.strip
+            expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr looks like a number less than
 18, but this could not be proved.
   After setting :attr to ‹"17"› -- which was read back as ‹"18"› -- the
@@ -794,8 +812,8 @@ Expected Example to validate that :attr looks like a number less than
   attribute, then you may need to change it to make this test pass, or
   do something else entirely.
             MESSAGE
-          }
-        }
+          },
+        },
       ) do
         def validation_matcher_scenario_args
           super.deep_merge(validation_options: { less_than: 18 })
@@ -819,7 +837,7 @@ Expected Example to validate that :attr looks like a number less than
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :integer,
-            less_than: 18
+            less_than: 18,
           )
 
           expect(record).to validate_numericality.is_less_than(18)
@@ -830,7 +848,7 @@ Expected Example to validate that :attr looks like a number less than
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :float,
-            less_than: 18
+            less_than: 18,
           )
 
           expect(record).to validate_numericality.is_less_than(18)
@@ -901,7 +919,7 @@ Expected Example not to validate that :attr looks like a number equal to
             model_name: 'Example',
             attribute_name: :attr,
             changing_values_with: :next_value,
-            expected_message: <<-MESSAGE.strip
+            expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr looks like a number equal to 18,
 but this could not be proved.
   After setting :attr to ‹"18"› -- which was read back as ‹"19"› -- the
@@ -916,8 +934,8 @@ but this could not be proved.
   attribute, then you may need to change it to make this test pass, or
   do something else entirely.
             MESSAGE
-          }
-        }
+          },
+        },
       ) do
         def validation_matcher_scenario_args
           super.deep_merge(validation_options: { equal_to: 18 })
@@ -941,7 +959,7 @@ but this could not be proved.
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :integer,
-            equal_to: 18
+            equal_to: 18,
           )
 
           expect(record).to validate_numericality.is_equal_to(18)
@@ -952,7 +970,7 @@ but this could not be proved.
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :float,
-            equal_to: 18
+            equal_to: 18,
           )
 
           expect(record).to validate_numericality.is_equal_to(18)
@@ -991,11 +1009,130 @@ but this could not be proved.
     end
   end
 
+  context 'qualified with is_other_than' do
+    context 'and validating with other_than' do
+      it 'accepts' do
+        record = build_record_validating_numericality(other_than: 18)
+        expect(record).to validate_numericality.is_other_than(18)
+      end
+
+      it 'rejects when used in the negative' do
+        record = build_record_validating_numericality(other_than: 18)
+
+        assertion = lambda do
+          expect(record).not_to validate_numericality.is_other_than(18)
+        end
+
+        expect(&assertion).to fail_with_message(<<~MESSAGE)
+Expected Example not to validate that :attr looks like a number other
+than 18, but this could not be proved.
+  After setting :attr to ‹"abcd"›, the matcher expected the Example to
+  be valid, but it was invalid instead, producing these validation
+  errors:
+
+  * attr: ["is not a number"]
+        MESSAGE
+      end
+
+      it_supports(
+        'ignoring_interference_by_writer',
+        tests: {
+          reject_if_qualified_but_changing_value_interferes: {
+            model_name: 'Example',
+            attribute_name: :attr,
+            changing_values_with: :next_value,
+            expected_message: <<-MESSAGE.strip,
+Expected Example to validate that :attr looks like a number other than
+18, but this could not be proved.
+  After setting :attr to ‹"18"› -- which was read back as ‹"19"› -- the
+  matcher expected the Example to be invalid, but it was valid instead.
+
+  As indicated in the message above, :attr seems to be changing certain
+  values as they are set, and this could have something to do with why
+  this test is failing. If you've overridden the writer method for this
+  attribute, then you may need to change it to make this test pass, or
+  do something else entirely.
+            MESSAGE
+          },
+        },
+      ) do
+        def validation_matcher_scenario_args
+          super.deep_merge(validation_options: { other_than: 18 })
+        end
+
+        def configure_validation_matcher(matcher)
+          matcher.is_other_than(18)
+        end
+      end
+
+      context 'when the attribute is a virtual attribute in an ActiveRecord model' do
+        it 'accepts' do
+          record = build_record_validating_numericality_of_virtual_attribute(
+            other_than: 18,
+          )
+          expect(record).to validate_numericality.is_other_than(18)
+        end
+      end
+
+      context 'when the column is an integer column' do
+        it 'accepts (and does not raise an error)' do
+          record = build_record_validating_numericality(
+            column_type: :integer,
+            other_than: 18,
+          )
+
+          expect(record).to validate_numericality.is_other_than(18)
+        end
+      end
+
+      context 'when the column is a float column' do
+        it 'accepts (and does not raise an error)' do
+          record = build_record_validating_numericality(
+            column_type: :float,
+            other_than: 18,
+          )
+
+          expect(record).to validate_numericality.is_other_than(18)
+        end
+      end
+
+      context 'when the column is a decimal column' do
+        it 'accepts (and does not raise an error)' do
+          record = build_record_validating_numericality(
+            column_type: :decimal,
+            other_than: 18,
+          )
+
+          expect(record).to validate_numericality.is_other_than(18)
+        end
+      end
+    end
+
+    context 'and not validating with other_than' do
+      it 'rejects since it does not disallow numbers that are not the value' do
+        record = build_record_validating_numericality
+
+        assertion = lambda do
+          expect(record).to validate_numericality.is_other_than(18)
+        end
+
+        message = <<-MESSAGE
+Expected Example to validate that :attr looks like a number other than
+18, but this could not be proved.
+  After setting :attr to ‹"18"›, the matcher expected the Example to be
+  invalid, but it was valid instead.
+        MESSAGE
+
+        expect(&assertion).to fail_with_message(message)
+      end
+    end
+  end
+
   context 'qualified with is_greater_than_or_equal to' do
     context 'validating with greater_than_or_equal_to' do
       it 'accepts' do
         record = build_record_validating_numericality(
-          greater_than_or_equal_to: 18
+          greater_than_or_equal_to: 18,
         )
         expect(record).
           to validate_numericality.
@@ -1030,7 +1167,7 @@ than or equal to 18, but this could not be proved.
             model_name: 'Example',
             attribute_name: :attr,
             changing_values_with: :next_value,
-            expected_message: <<-MESSAGE.strip
+            expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr looks like a number greater than
 or equal to 18, but this could not be proved.
   After setting :attr to ‹"17"› -- which was read back as ‹"18"› -- the
@@ -1042,12 +1179,12 @@ or equal to 18, but this could not be proved.
   attribute, then you may need to change it to make this test pass, or
   do something else entirely.
             MESSAGE
-          }
-        }
+          },
+        },
       ) do
         def validation_matcher_scenario_args
           super.deep_merge(
-            validation_options: { greater_than_or_equal_to: 18 }
+            validation_options: { greater_than_or_equal_to: 18 },
           )
         end
 
@@ -1070,7 +1207,7 @@ or equal to 18, but this could not be proved.
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :integer,
-            greater_than_or_equal_to: 18
+            greater_than_or_equal_to: 18,
           )
 
           expect(record).
@@ -1083,7 +1220,7 @@ or equal to 18, but this could not be proved.
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :float,
-            greater_than_or_equal_to: 18
+            greater_than_or_equal_to: 18,
           )
 
           expect(record).
@@ -1162,7 +1299,7 @@ than 18, but this could not be proved.
             model_name: 'Example',
             attribute_name: :attr,
             changing_values_with: :next_value,
-            expected_message: <<-MESSAGE.strip
+            expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr looks like a number greater than
 18, but this could not be proved.
   After setting :attr to ‹"18"› -- which was read back as ‹"19"› -- the
@@ -1174,8 +1311,8 @@ Expected Example to validate that :attr looks like a number greater than
   attribute, then you may need to change it to make this test pass, or
   do something else entirely.
             MESSAGE
-          }
-        }
+          },
+        },
       ) do
         def validation_matcher_scenario_args
           super.deep_merge(validation_options: { greater_than: 18 })
@@ -1199,7 +1336,7 @@ Expected Example to validate that :attr looks like a number greater than
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :integer,
-            greater_than: 18
+            greater_than: 18,
           )
 
           expect(record).
@@ -1212,7 +1349,7 @@ Expected Example to validate that :attr looks like a number greater than
         it 'accepts (and does not raise an error)' do
           record = build_record_validating_numericality(
             column_type: :float,
-            greater_than: 18
+            greater_than: 18,
           )
 
           expect(record).
@@ -1392,7 +1529,7 @@ could not be proved.
       specify 'such as validating even but testing that only_integer is validated' do
         record = build_record_validating_numericality(
           even: true,
-          greater_than: 18
+          greater_than: 18,
         )
 
         assertion = lambda do
@@ -1445,7 +1582,7 @@ than 18, but this could not be proved.
       specify 'such as validating greater_than_or_equal_to (+ even) but testing that greater_than is validated' do
         record = build_record_validating_numericality(
           even: true,
-          greater_than_or_equal_to: 18
+          greater_than_or_equal_to: 18,
         )
 
         assertion = lambda do
@@ -1469,7 +1606,7 @@ greater than 18, but this could not be proved.
       specify 'such as validating odd (+ greater_than) but testing that even is validated' do
         record = build_record_validating_numericality(
           odd: true,
-          greater_than: 18
+          greater_than: 18,
         )
 
         assertion = lambda do
@@ -1497,7 +1634,7 @@ greater than 18, but this could not be proved.
       specify 'such as validating greater_than_or_equal_to (+ odd) but testing that is_less_than_or_equal_to is validated' do
         record = build_record_validating_numericality(
           odd: true,
-          greater_than_or_equal_to: 99
+          greater_than_or_equal_to: 99,
         )
 
         assertion = lambda do
@@ -1522,7 +1659,7 @@ than or equal to 99, but this could not be proved.
         record = build_record_validating_numericality(
           only_integer: true,
           greater_than_or_equal_to: 18,
-          less_than: 99
+          less_than: 99,
         )
 
         assertion = lambda do
@@ -1549,7 +1686,7 @@ than 18 and less than 99, but this could not be proved.
       specify 'such as testing greater_than (+ only_integer) with lower value' do
         record = build_record_validating_numericality(
           only_integer: true,
-          greater_than: 19
+          greater_than: 19,
         )
 
         assertion = lambda do
@@ -1577,7 +1714,7 @@ than 18, but this could not be proved.
       specify 'such as testing greater_than (+ only_integer) with higher value' do
         record = build_record_validating_numericality(
           only_integer: true,
-          greater_than: 17
+          greater_than: 17,
         )
 
         assertion = lambda do
@@ -1601,7 +1738,7 @@ than 18, but this could not be proved.
       specify 'such as testing greater_than (+ even) with lower value' do
         record = build_record_validating_numericality(
           even: true,
-          greater_than: 20
+          greater_than: 20,
         )
 
         assertion = lambda do
@@ -1629,7 +1766,7 @@ greater than 18, but this could not be proved.
       specify 'such as testing greater than (+ even) with higher value' do
         record = build_record_validating_numericality(
           even: true,
-          greater_than: 16
+          greater_than: 16,
         )
 
         assertion = lambda do
@@ -1653,7 +1790,7 @@ greater than 18, but this could not be proved.
       specify 'such as testing less_than_or_equal_to (+ odd) with lower value' do
         record = build_record_validating_numericality(
           odd: true,
-          less_than_or_equal_to: 101
+          less_than_or_equal_to: 101,
         )
 
         assertion = lambda do
@@ -1677,7 +1814,7 @@ than or equal to 99, but this could not be proved.
       specify 'such as testing less_than_or_equal_to (+ odd) with higher value' do
         record = build_record_validating_numericality(
           odd: true,
-          less_than_or_equal_to: 97
+          less_than_or_equal_to: 97,
         )
 
         assertion = lambda do
@@ -1707,7 +1844,7 @@ than or equal to 99, but this could not be proved.
         record = build_record_validating_numericality(
           only_integer: true,
           greater_than: 19,
-          less_than: 99
+          less_than: 99,
         )
 
         assertion = lambda do
@@ -1737,7 +1874,7 @@ than 18 and less than 99, but this could not be proved.
         record = build_record_validating_numericality(
           only_integer: true,
           greater_than: 18,
-          less_than: 100
+          less_than: 100,
         )
 
         assertion = lambda do
@@ -1778,7 +1915,7 @@ than 18 and less than 99, but this could not be proved.
 
     it do
       record = build_record_validating_numericality(
-        greater_than_or_equal_to: 100_000
+        greater_than_or_equal_to: 100_000,
       )
       expect(record).
         to validate_numericality.
@@ -1787,7 +1924,7 @@ than 18 and less than 99, but this could not be proved.
 
     it do
       record = build_record_validating_numericality(
-        less_than_or_equal_to: 100_000
+        less_than_or_equal_to: 100_000,
       )
       expect(record).
         to validate_numericality.
@@ -1829,7 +1966,7 @@ than 18 and less than 99, but this could not be proved.
           model_name: 'Example',
           attribute_name: :attr,
           changing_values_with: :numeric_value,
-          expected_message: <<-MESSAGE.strip
+          expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr looks like a number, but this
 could not be proved.
   After setting :attr to ‹"abcd"› -- which was read back as ‹"1"› -- the
@@ -1841,8 +1978,8 @@ could not be proved.
   attribute, then you may need to change it to make this test pass, or
   do something else entirely.
           MESSAGE
-        }
-      }
+        },
+      },
     )
 
     def validation_matcher_scenario_args
@@ -1850,12 +1987,62 @@ could not be proved.
     end
   end
 
+  describe 'using in the negative form without numericality validations' do
+    context 'when qualified with is_greater_than' do
+      it 'accepts' do
+        record = (define_model :example, attr: :integer).new
+
+        expect(record).not_to validate_numericality.is_greater_than(18)
+      end
+    end
+
+    context 'when qualified with is_greater_than_or_equal_to' do
+      it 'accepts' do
+        record = (define_model :example, attr: :integer).new
+
+        expect(record).not_to validate_numericality.is_greater_than_or_equal_to(18)
+      end
+    end
+
+    context 'when qualified with is_less_than_or_equal_to' do
+      it 'accepts' do
+        record = (define_model :example, attr: :integer).new
+
+        expect(record).not_to validate_numericality.is_less_than_or_equal_to(18)
+      end
+    end
+
+    context 'when qualified with is_less_than' do
+      it 'accepts' do
+        record = (define_model :example, attr: :integer).new
+
+        expect(record).not_to validate_numericality.is_less_than(18)
+      end
+    end
+
+    context 'when qualified with is_equal_to' do
+      it 'accepts' do
+        record = (define_model :example, attr: :integer).new
+
+        expect(record).not_to validate_numericality.is_equal_to(18)
+      end
+    end
+
+    context 'when qualified with is_other_than' do
+      it 'accepts' do
+        record = (define_model :example, attr: :integer).new
+
+        expect(record).not_to validate_numericality.is_other_than(18)
+      end
+    end
+  end
+
   describe '#description' do
     context 'qualified with nothing' do
       it 'describes that it allows numbers' do
         matcher = validate_numericality_of(:attr)
         expect(matcher.description).to eq(
-          'validate that :attr looks like a number'
+          'validate that :attr looks like a number',
         )
       end
     end
@@ -1864,7 +2051,7 @@ could not be proved.
       it 'describes that it allows integers' do
         matcher = validate_numericality_of(:attr).only_integer
         expect(matcher.description).to eq(
-          'validate that :attr looks like an integer'
+          'validate that :attr looks like an integer',
         )
       end
     end
@@ -1874,7 +2061,7 @@ could not be proved.
         it "describes that it allows #{qualifier[:name]} numbers" do
           matcher = validate_numericality_of(:attr).__send__(qualifier[:name])
           expect(matcher.description).to eq(
-            "validate that :attr looks like an #{qualifier[:name]} number"
+            "validate that :attr looks like an #{qualifier[:name]} number",
           )
         end
       end
@@ -1889,20 +2076,20 @@ could not be proved.
             __send__(qualifier[:name], 18)
 
           expect(matcher.description).to eq(
-            "validate that :attr looks like a number #{comparison_phrase} 18"
+            "validate that :attr looks like a number #{comparison_phrase} 18",
           )
         end
       end
     end
 
     context 'qualified with odd + is_greater_than_or_equal_to' do
-      it "describes that it allows odd numbers greater than or equal to a certain value" do
+      it 'describes that it allows odd numbers greater than or equal to a certain value' do
         matcher = validate_numericality_of(:attr).
           odd.
           is_greater_than_or_equal_to(18)
 
         expect(matcher.description).to eq(
-          'validate that :attr looks like an odd number greater than or equal to 18'
+          'validate that :attr looks like an odd number greater than or equal to 18',
         )
       end
     end
@@ -1915,7 +2102,7 @@ could not be proved.
           is_less_than_or_equal_to(100)
 
         expect(matcher.description).to eq(
-          'validate that :attr looks like an integer greater than 18 and less than or equal to 100'
+          'validate that :attr looks like an integer greater than 18 and less than or equal to 100',
         )
       end
     end
@@ -1924,7 +2111,7 @@ could not be proved.
       it 'describes that it relies upon a strict validation' do
         matcher = validate_numericality_of(:attr).strict
         expect(matcher.description).to eq(
-          'validate that :attr looks like a number, raising a validation exception on failure'
+          'validate that :attr looks like a number, raising a validation exception on failure',
         )
       end
 
@@ -1932,13 +2119,149 @@ could not be proved.
         it 'places the comparison description after "strictly"' do
           matcher = validate_numericality_of(:attr).is_less_than(18).strict
           expect(matcher.description).to eq(
-            'validate that :attr looks like a number less than 18, raising a validation exception on failure'
+            'validate that :attr looks like a number less than 18, raising a validation exception on failure',
           )
         end
       end
     end
   end
 
+  context 'qualified with in' do
+    context 'validating with in' do
+      it 'accepts' do
+        record = build_record_validating_numericality(
+          in: 1..10,
+        )
+        expect(record).to validate_numericality.is_in(1..10)
+      end
+
+      it 'rejects when used in the negative' do
+        record = build_record_validating_numericality(
+          in: 1..10,
+        )
+
+        assertion = lambda do
+          expect(record).not_to validate_numericality.is_in(1..10)
+        end
+
+        expect(&assertion).to fail_with_message(<<~MESSAGE)
+Expected Example not to validate that :attr looks like a number from ‹1›
+to ‹10›, but this could not be proved.
+  After setting :attr to ‹"abcd"›, the matcher expected the Example to
+  be valid, but it was invalid instead, producing these validation
+  errors:
+
+  * attr: ["is not a number"]
+        MESSAGE
+      end
+
+      it_supports(
+        'ignoring_interference_by_writer',
+        tests: {
+          reject_if_qualified_but_changing_value_interferes: {
+            model_name: 'Example',
+            attribute_name: :attr,
+            changing_values_with: :next_value,
+            expected_message: <<-MESSAGE.strip,
+Expected Example to validate that :attr looks like a number from ‹1› to
+‹10›, but this could not be proved.
+  After setting :attr to ‹"10"› -- which was read back as ‹"11"› -- the
+  matcher expected the Example to be valid, but it was invalid instead,
+  producing these validation errors:
+
+  * attr: ["must be in 1..10"]
+
+  As indicated in the message above, :attr seems to be changing certain
+  values as they are set, and this could have something to do with why
+  this test is failing. If you've overridden the writer method for this
+  attribute, then you may need to change it to make this test pass, or
+  do something else entirely.
+            MESSAGE
+          },
+        },
+      ) do
+        def validation_matcher_scenario_args
+          super.deep_merge(
+            validation_options: { in: 1..10 },
+          )
+        end
+
+        def configure_validation_matcher(matcher)
+          matcher.is_in(1..10)
+        end
+      end
+
+      context 'when the attribute is a virtual attribute in an ActiveRecord model' do
+        it 'accepts' do
+          record = build_record_validating_numericality_of_virtual_attribute(
+            in: 1..10,
+          )
+          expect(record).to validate_numericality.
+            is_in(1..10)
+        end
+      end
+
+      context 'when the column is an integer column' do
+        it 'accepts (and does not raise an error)' do
+          record = build_record_validating_numericality(
+            column_type: :integer,
+            in: 1..10,
+          )
+
+          expect(record).
+            to validate_numericality.
+            is_in(1..10)
+        end
+      end
+
+      context 'when the column is a float column' do
+        it 'accepts (and does not raise an error)' do
+          record = build_record_validating_numericality(
+            column_type: :float,
+            in: 1..10,
+          )
+
+          expect(record).
+            to validate_numericality.
+            is_in(1..10)
+        end
+      end
+
+      context 'when the column is a decimal column' do
+        it 'accepts (and does not raise an error)' do
+          record = build_record_validating_numericality(
+            column_type: :decimal,
+            in: 1..10,
+          )
+
+          expect(record).
+            to validate_numericality.
+            is_in(1..10)
+        end
+      end
+    end
+
+    context 'not validating with in' do
+      it 'rejects since it does not disallow numbers that are not in the range specified' do
+        record = build_record_validating_numericality
+
+        assertion = lambda do
+          expect(record).to validate_numericality.
+            is_in(1..10)
+        end
+
+        message = <<-MESSAGE
+Expected Example to validate that :attr looks like a number from ‹1› to
+‹10›, but this could not be proved.
+  After setting :attr to ‹"11"›, the matcher expected the Example to be
+  invalid, but it was valid instead.
+        MESSAGE
+
+        expect(&assertion).to fail_with_message(message)
+      end
+    end
+  end
+
   def build_validation_options(args)
     combination = args.fetch(:for)
 
@@ -1954,7 +2277,11 @@ could not be proved.
 
     combination.each do |qualifier|
       args = self.class.default_qualifier_arguments.fetch(qualifier[:name])
-      matcher.__send__(qualifier[:name], *args)
+      if args
+        matcher.__send__(qualifier[:name], args)
+      else
+        matcher.__send__(qualifier[:name])
+      end
     end
   end
 
@@ -2003,7 +2330,7 @@ could not be proved.
   def validation_matcher_scenario_args
     super.deep_merge(
       matcher_name: :validate_numericality_of,
-      model_creator: :active_record
+      model_creator: :active_record,
     )
   end
 end
