@@ -12,15 +12,15 @@ describe Shoulda::Matchers::ActiveRecord::ValidateUniquenessOfMatcher, type: :mo
           record = build_record_validating_uniqueness(
             scopes: [
               build_attribute(name: :scope1),
-              { name: :scope2 }
-            ]
+              { name: :scope2 },
+            ],
           )
           expect(record).to validate_uniqueness.scoped_to(:scope1, :scope2)
         end
 
         it 'still accepts if the scope is unset beforehand' do
           record = build_record_validating_uniqueness(
-            scopes: [ build_attribute(name: :scope, value: nil) ]
+            scopes: [build_attribute(name: :scope, value: nil)],
           )
 
           expect(record).to validate_uniqueness.scoped_to(:scope)
@@ -32,8 +32,8 @@ describe Shoulda::Matchers::ActiveRecord::ValidateUniquenessOfMatcher, type: :mo
           record = create_record_validating_uniqueness(
             scopes: [
               build_attribute(name: :scope1),
-              { name: :scope2 }
-            ]
+              { name: :scope2 },
+            ],
           )
 
           expect(record).to validate_uniqueness.scoped_to(:scope1, :scope2)
@@ -41,7 +41,7 @@ describe Shoulda::Matchers::ActiveRecord::ValidateUniquenessOfMatcher, type: :mo
 
         it 'still accepts if the scope is unset beforehand' do
           record = create_record_validating_uniqueness(
-            scopes: [ build_attribute(name: :scope, value: nil) ]
+            scopes: [build_attribute(name: :scope, value: nil)],
           )
 
           expect(record).to validate_uniqueness.scoped_to(:scope)
@@ -51,11 +51,11 @@ describe Shoulda::Matchers::ActiveRecord::ValidateUniquenessOfMatcher, type: :mo
 
     context "when more than one record exists that has the next version of the attribute's value" do
       it 'accepts' do
-        value1 = dummy_value_for(value_type, array: array)
+        value1 = dummy_value_for(value_type, array:)
         value2 = next_version_of(value1, value_type)
         value3 = next_version_of(value2, value_type)
         model = define_model_validating_uniqueness(
-          scopes: [ build_attribute(name: :scope) ]
+          scopes: [build_attribute(name: :scope)],
         )
         create_record_from(model, scope: value2)
         create_record_from(model, scope: value3)
@@ -70,9 +70,9 @@ describe Shoulda::Matchers::ActiveRecord::ValidateUniquenessOfMatcher, type: :mo
         record = build_record_validating_uniqueness(
           scopes: [
             build_attribute(name: :scope1),
-            build_attribute(name: :scope2)
+            build_attribute(name: :scope2),
           ],
-          additional_attributes: [:other]
+          additional_attributes: [:other],
         )
 
         assertion = lambda do
@@ -98,7 +98,7 @@ proved.
         record = build_record_validating_uniqueness(
           scopes: [
             build_attribute(name: :scope1),
-            build_attribute(name: :scope2)
+            build_attribute(name: :scope2),
           ],
         )
 
@@ -122,8 +122,8 @@ within the scope of :scope1, but this could not be proved.
     context 'when a different scope is specified' do
       it 'rejects with an appropriate failure message' do
         record = build_record_validating_uniqueness(
-          scopes: [ build_attribute(name: :other) ],
-          additional_attributes: [:scope]
+          scopes: [build_attribute(name: :other)],
+          additional_attributes: [:scope],
         )
         assertion = lambda do
           expect(record).
@@ -145,7 +145,7 @@ within the scope of :scope, but this could not be proved.
     context 'when no scope is specified' do
       it 'rejects with an appropriate failure message' do
         record = build_record_validating_uniqueness(
-          scopes: [ build_attribute(name: :scope) ]
+          scopes: [build_attribute(name: :scope)],
         )
 
         assertion = lambda do
@@ -165,7 +165,7 @@ this could not be proved.
       context 'if the scope attribute is unset in the record given to the matcher' do
         it 'rejects with an appropriate failure message' do
           record = build_record_validating_uniqueness(
-            scopes: [ build_attribute(name: :scope, value: nil) ]
+            scopes: [build_attribute(name: :scope, value: nil)],
           )
 
           assertion = lambda do
@@ -188,7 +188,7 @@ this could not be proved.
       context 'when there is more than one scope' do
         it 'rejects with an appropriate failure message (and does not raise an error)' do
           record = build_record_validating_uniqueness(
-            scopes: [ build_attribute(name: :scope) ]
+            scopes: [build_attribute(name: :scope)],
           )
 
           assertion = lambda do
@@ -208,13 +208,13 @@ within the scope of :non_existent, but this could not be proved.
       context 'when there is more than one scope' do
         it 'rejects with an appropriate failure message (and does not raise an error)' do
           record = build_record_validating_uniqueness(
-            scopes: [ build_attribute(name: :scope) ]
+            scopes: [build_attribute(name: :scope)],
           )
 
           assertion = lambda do
             expect(record).to validate_uniqueness.scoped_to(
               :non_existent1,
-              :non_existent2
+              :non_existent2,
             )
           end
 
@@ -265,24 +265,24 @@ not be proved.
               'Example',
               attribute_name => :string,
               scope1: column_type,
-              scope2: column_type
+              scope2: column_type,
             ) do |m|
               m.validates_uniqueness_of(
                 attribute_name,
                 scope: [:scope1],
-                message: 'first message'
+                message: 'first message',
               )
               m.validates_uniqueness_of(
                 attribute_name,
                 scope: [:scope2],
-                message: 'second message'
+                message: 'second message',
               )
             end
 
             model.create!(
               attribute_name => dummy_value_for(:string),
               scope1: dummy_value_for(column_type),
-              scope2: dummy_value_for(column_type)
+              scope2: dummy_value_for(column_type),
             )
 
             expect(model.new).
@@ -319,9 +319,9 @@ not be proved.
 
     define_method(:build_attribute) do |attribute_options|
       attribute_options.deep_merge(
-        column_type: column_type,
-        value_type: value_type,
-        options: { array: array }
+        column_type:,
+        value_type:,
+        options: { array: },
       )
     end
   end
@@ -352,7 +352,7 @@ this could not be proved.
       it 'accepts' do
         record = build_record_validating_uniqueness(
           attribute_type: :string,
-          attribute_options: { limit: 1 }
+          attribute_options: { limit: 1 },
         )
 
         expect(record).to validate_uniqueness
@@ -405,7 +405,7 @@ this could not be proved.
           it 'can save the subject without the attributes being set' do
             options = {
               attribute_name: :attr,
-              additional_attributes: [:required_attribute]
+              additional_attributes: [:required_attribute],
             }
             model = define_model_validating_uniqueness(options) do |m|
               m.validates_presence_of :attr
@@ -434,8 +434,8 @@ this could not be proved.
             it 'can save the subject' do
               options = {
                 additional_attributes: [
-                  { name: :required_attribute, options: { null: false } }
-                ]
+                  { name: :required_attribute, options: { null: false } },
+                ],
               }
               model = define_model_validating_uniqueness(options)
               record = model.new
@@ -449,8 +449,8 @@ this could not be proved.
             it 'raises a useful exception' do
               options = {
                 additional_attributes: [
-                  { name: :required_attribute, options: { null: false } }
-                ]
+                  { name: :required_attribute, options: { null: false } },
+                ],
               }
               model = define_model_validating_uniqueness(options)
 
@@ -459,7 +459,7 @@ this could not be proved.
               end
 
               expect(&assertion).to raise_error(
-                described_class::ExistingRecordInvalid
+                described_class::ExistingRecordInvalid,
               )
             end
           end
@@ -468,7 +468,7 @@ this could not be proved.
         context 'and the model has required attributes other than the attribute being validated' do
           it 'can save the subject without the attributes being set' do
             options = {
-              additional_attributes: [:required_attribute]
+              additional_attributes: [:required_attribute],
             }
             model = define_model_validating_uniqueness(options) do |m|
               m.validates_presence_of :required_attribute
@@ -493,8 +493,8 @@ this could not be proved.
           it 'can save the subject' do
             options = {
               additional_attributes: [
-                { name: :required_attribute, options: { null: false } }
-              ]
+                { name: :required_attribute, options: { null: false } },
+              ],
             }
             model = define_model_validating_uniqueness(options)
 
@@ -506,7 +506,7 @@ this could not be proved.
         context 'and the model has required attributes other than the attribute being validated, set beforehand' do
           it 'can save the subject' do
             options = {
-              additional_attributes: [:required_attribute]
+              additional_attributes: [:required_attribute],
             }
             model = define_model_validating_uniqueness(options) do |m|
               m.validates_presence_of :required_attribute
@@ -522,7 +522,7 @@ this could not be proved.
     context 'when the validation has no scope and a scope is specified' do
       it 'rejects with an appropriate failure message' do
         model = define_model_validating_uniqueness(
-          additional_attributes: [:other]
+          additional_attributes: [:other],
         )
         create_record_from(model)
         record = build_record_from(model)
@@ -547,7 +547,7 @@ within the scope of :other, but this could not be proved.
         it 'rejects with an appropriate failure message' do
           record = build_record_validating_uniqueness(
             attribute_value: 'some value',
-            validation_options: { message: 'bad value' }
+            validation_options: { message: 'bad value' },
           )
 
           assertion = lambda do
@@ -576,7 +576,7 @@ this could not be proved.
           it 'rejects with an appropriate failure message' do
             record = build_record_validating_uniqueness(
               attribute_value: 'some value',
-              validation_options: { message: 'something else entirely' }
+              validation_options: { message: 'something else entirely' },
             )
 
             assertion = lambda do
@@ -606,7 +606,7 @@ proved.
         context 'when the given and actual messages match' do
           it 'accepts' do
             record = build_record_validating_uniqueness(
-              validation_options: { message: 'bad value' }
+              validation_options: { message: 'bad value' },
             )
             expect(record).
               to validate_uniqueness.
@@ -620,7 +620,7 @@ proved.
           it 'rejects with an appropriate failure message' do
             record = build_record_validating_uniqueness(
               attribute_value: 'some value',
-              validation_options: { message: 'something else entirely' }
+              validation_options: { message: 'something else entirely' },
             )
 
             assertion = lambda do
@@ -650,7 +650,7 @@ proved.
         context 'when the given and actual messages match' do
           it 'accepts' do
             record = build_record_validating_uniqueness(
-              validation_options: { message: 'bad value' }
+              validation_options: { message: 'bad value' },
             )
             expect(record).
               to validate_uniqueness.
@@ -668,7 +668,7 @@ proved.
           attribute_name: :attr,
           default_value: 'some value',
           changing_values_with: :next_value,
-          expected_message: <<-MESSAGE.strip
+          expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr is case-sensitively unique, but
 this could not be proved.
   After taking the given Example, whose :attr is ‹"some valuf"›, and
@@ -687,15 +687,15 @@ this could not be proved.
   yourself, or do something different altogether.
 
           MESSAGE
-        }
-      }
+        },
+      },
     )
 
     it 'fails when used in the negative' do
       assertion = lambda do
         record = build_record_validating_uniqueness(
           attribute_type: :string,
-          attribute_options: { limit: 1 }
+          attribute_options: { limit: 1 },
         )
 
         expect(record).not_to validate_uniqueness
@@ -730,8 +730,8 @@ but this could not be proved.
         record = build_record_validating_uniqueness(
           scopes: [
             { type: :boolean, name: :scope1, value: true },
-            { type: :boolean, name: :scope2, value: true }
-          ]
+            { type: :boolean, name: :scope2, value: true },
+          ],
         )
         expect(record).to validate_uniqueness.scoped_to(:scope1, :scope2)
       end
@@ -740,8 +740,8 @@ but this could not be proved.
         record = build_record_validating_uniqueness(
           scopes: [
             { type: :boolean, name: :scope1, value: false },
-            { type: :boolean, name: :scope2, value: false }
-          ]
+            { type: :boolean, name: :scope2, value: false },
+          ],
         )
         expect(record).to validate_uniqueness.scoped_to(:scope1, :scope2)
       end
@@ -750,8 +750,8 @@ but this could not be proved.
         record = build_record_validating_uniqueness(
           scopes: [
             { type: :boolean, name: :scope1, value: true },
-            { type: :boolean, name: :scope2, value: false }
-          ]
+            { type: :boolean, name: :scope2, value: false },
+          ],
         )
         expect(record).to validate_uniqueness.scoped_to(:scope1, :scope2)
       end
@@ -764,7 +764,7 @@ but this could not be proved.
       context 'when one of the scoped attributes is an enum' do
         it 'accepts' do
           record = build_record_validating_scoped_uniqueness_with_enum(
-            enum_scope: :scope
+            enum_scope: :scope,
           )
           expect(record).to validate_uniqueness.scoped_to(:scope)
         end
@@ -774,7 +774,7 @@ but this could not be proved.
             record = build_record_validating_scoped_uniqueness_with_enum(
               enum_scope: :scope1,
               additional_scopes: [:scope2],
-              additional_attributes: [:other]
+              additional_attributes: [:other],
             )
 
             assertion = lambda do
@@ -799,7 +799,7 @@ proved.
           it 'rejects with an appropriate failure message' do
             record = build_record_validating_scoped_uniqueness_with_enum(
               enum_scope: :scope1,
-              additional_scopes: [:scope2]
+              additional_scopes: [:scope2],
             )
 
             assertion = lambda do
@@ -829,6 +829,21 @@ within the scope of :scope1, but this could not be proved.
         column_type: :datetime
     end
 
+    context 'when one of the scoped attributes is a timestamp column (using DateTime)' do
+      include_context 'it supports scoped attributes of a certain type',
+        column_type: :timestamp
+    end
+
+    context 'when one of the scoped attributes is a timestamp with time zone column (using DateTime)' do
+      include_context 'it supports scoped attributes of a certain type',
+        column_type: :timestamptz
+    end
+
+    context 'when one of the scoped attributes is a time column (using Time)' do
+      include_context 'it supports scoped attributes of a certain type',
+        column_type: :time
+    end
+
     context 'when one of the scoped attributes is a datetime column (using Time)' do
       include_context 'it supports scoped attributes of a certain type',
         column_type: :datetime,
@@ -847,50 +862,7 @@ within the scope of :scope1, but this could not be proved.
       end
     end
 
-    if (
-      database_supports_array_columns? &&
-      active_record_supports_array_columns? &&
-      active_record_uniqueness_supports_array_columns?
-    )
-      context 'when one of the scoped attributes is a array-of-string column' do
-        include_examples 'it supports scoped attributes of a certain type',
-          column_type: :string,
-          array: true
-      end
-
-      context 'when one of the scoped attributes is an array-of-integer column' do
-        include_examples 'it supports scoped attributes of a certain type',
-          column_type: :integer,
-          array: true
-      end
-
-      context 'when one of the scoped attributes is an array-of-date column' do
-        include_examples 'it supports scoped attributes of a certain type',
-          column_type: :date,
-          array: true
-      end
-
-      context 'when one of the scoped attributes is an array-of-datetime column (using DateTime)' do
-        include_examples 'it supports scoped attributes of a certain type',
-          column_type: :datetime,
-          array: true
-      end
-
-      context 'when one of the scoped attributes is an array-of-datetime column (using Time)' do
-        include_examples 'it supports scoped attributes of a certain type',
-          column_type: :datetime,
-          value_type: :time,
-          array: true
-      end
-
-      context 'when one of the scoped attributes is an array-of-text column' do
-        include_examples 'it supports scoped attributes of a certain type',
-          column_type: :text,
-          array: true
-      end
-    end
-
-    context "when an existing record that is not the first has a nil value for the scoped attribute" do
+    context 'when an existing record that is not the first has a nil value for the scoped attribute' do
       # This fails intermittently
       # it 'still works' do
         # model = define_model_validating_uniqueness(scopes: [:scope])
@@ -908,7 +880,7 @@ within the scope of :scope1, but this could not be proved.
       it 'accepts' do
         record = build_record_validating_uniqueness(
           attribute_type: :string,
-          validation_options: { case_sensitive: true }
+          validation_options: { case_sensitive: true },
         )
 
         expect(record).to validate_uniqueness
@@ -934,7 +906,7 @@ within the scope of :scope1, but this could not be proved.
         record = build_record_validating_uniqueness(
           attribute_type: :string,
           attribute_value: 'some value',
-          validation_options: { case_sensitive: true }
+          validation_options: { case_sensitive: true },
         )
 
         assertion = lambda do
@@ -960,7 +932,7 @@ but this could not be proved.
       it 'rejects with an appropriate failure message' do
         record = build_record_validating_uniqueness(
           attribute_type: :string,
-          validation_options: { case_sensitive: false }
+          validation_options: { case_sensitive: false },
         )
 
         assertion = lambda do
@@ -987,7 +959,7 @@ this could not be proved.
       it 'accepts' do
         record = build_record_validating_uniqueness(
           attribute_type: :string,
-          validation_options: { case_sensitive: false }
+          validation_options: { case_sensitive: false },
         )
 
         expect(record).to validate_uniqueness.case_insensitive
@@ -1001,7 +973,7 @@ this could not be proved.
             attribute_name: :attr,
             default_value: 'some value',
             changing_values_with: :next_value,
-            expected_message: <<-MESSAGE.strip
+            expected_message: <<-MESSAGE.strip,
 Expected Example to validate that :attr is case-insensitively unique,
 but this could not be proved.
   After taking the given Example, whose :attr is ‹"some valuf"›, and
@@ -1019,8 +991,8 @@ but this could not be proved.
   of the uniqueness matcher. Otherwise, you may need to write the test
   yourself, or do something different altogether.
             MESSAGE
-          }
-        }
+          },
+        },
       )
 
       def validation_matcher_scenario_args
@@ -1037,7 +1009,7 @@ but this could not be proved.
     context 'given a new record whose attribute is nil' do
       it 'accepts' do
         model = define_model_validating_uniqueness(
-          validation_options: { allow_nil: true }
+          validation_options: { allow_nil: true },
         )
         record = build_record_from(model, attribute_name => nil)
         expect(record).to validate_uniqueness.allow_nil
@@ -1047,7 +1019,7 @@ but this could not be proved.
     context 'given an existing record whose attribute is nil' do
       it 'accepts' do
         model = define_model_validating_uniqueness(
-          validation_options: { allow_nil: true }
+          validation_options: { allow_nil: true },
         )
         record = create_record_from(model, attribute_name => nil)
         expect(record).to validate_uniqueness.allow_nil
@@ -1109,7 +1081,7 @@ long as it is not nil, but this could not be proved.
     context 'given a new record whose attribute is nil' do
       it 'accepts' do
         model = define_model_validating_uniqueness(
-          validation_options: { allow_blank: true }
+          validation_options: { allow_blank: true },
         )
         record = build_record_from(model, attribute_name => nil)
         expect(record).to validate_uniqueness.allow_blank
@@ -1119,7 +1091,7 @@ long as it is not nil, but this could not be proved.
     context 'given an existing record whose attribute is nil' do
       it 'accepts' do
         model = define_model_validating_uniqueness(
-          validation_options: { allow_blank: true }
+          validation_options: { allow_blank: true },
         )
         record = create_record_from(model, attribute_name => nil)
         expect(record).to validate_uniqueness.allow_blank
@@ -1130,7 +1102,7 @@ long as it is not nil, but this could not be proved.
       it 'accepts' do
         model = define_model_validating_uniqueness(
           attribute_type: :string,
-          validation_options: { allow_blank: true }
+          validation_options: { allow_blank: true },
         )
         record = build_record_from(model, attribute_name => '')
         expect(record).to validate_uniqueness.allow_blank
@@ -1141,44 +1113,34 @@ long as it is not nil, but this could not be proved.
       it 'accepts' do
         model = define_model_validating_uniqueness(
           attribute_type: :string,
-          validation_options: { allow_blank: true }
+          validation_options: { allow_blank: true },
         )
         record = create_record_from(model, attribute_name => '')
         expect(record).to validate_uniqueness.allow_blank
       end
     end
 
-    if active_record_supports_has_secure_password?
-      context 'when the model is declared with has_secure_password' do
-        context 'given a record whose attribute is nil' do
-          it 'accepts' do
-            model = define_model_validating_uniqueness(
-              validation_options: { allow_blank: true },
-              additional_attributes: [{ name: :password_digest, type: :string }]
-            ) do |m|
-              m.has_secure_password
-            end
-
-            record = build_record_from(model, attribute_name => nil)
-
-            expect(record).to validate_uniqueness.allow_blank
-          end
+    context 'when the model is declared with has_secure_password' do
+      context 'given a record whose attribute is nil' do
+        it 'accepts' do
+          model = define_model_validating_uniqueness(
+            validation_options: { allow_blank: true },
+            additional_attributes: [{ name: :password_digest, type: :string }], &:has_secure_password
+          )
+          record = build_record_from(model, attribute_name => nil)
+          expect(record).to validate_uniqueness.allow_blank
         end
+      end
 
-        context 'given a record whose attribute is empty' do
-          it 'accepts' do
-            model = define_model_validating_uniqueness(
-              attribute_type: :string,
-              validation_options: { allow_blank: true },
-              additional_attributes: [{ name: :password_digest, type: :string }]
-            ) do |m|
-              m.has_secure_password
-            end
-
-            record = build_record_from(model, attribute_name => '')
-
-            expect(record).to validate_uniqueness.allow_blank
-          end
+      context 'given a record whose attribute is empty' do
+        it 'accepts' do
+          model = define_model_validating_uniqueness(
+            attribute_type: :string,
+            validation_options: { allow_blank: true },
+            additional_attributes: [{ name: :password_digest, type: :string }], &:has_secure_password
+          )
+          record = build_record_from(model, attribute_name => '')
+          expect(record).to validate_uniqueness.allow_blank
         end
       end
     end
@@ -1236,7 +1198,7 @@ long as it is not blank, but this could not be proved.
     context 'given a new record whose attribute is empty' do
       it 'rejects with an appropriate failure message' do
         model = define_model_validating_uniqueness(
-          attribute_type: :string
+          attribute_type: :string,
         )
         record = build_record_from(model, attribute_name => '')
 
@@ -1262,7 +1224,7 @@ long as it is not blank, but this could not be proved.
     context 'given an existing record whose attribute is empty' do
       it 'rejects with an appropriate failure message' do
         model = define_model_validating_uniqueness(
-          attribute_type: :string
+          attribute_type: :string,
         )
         record = create_record_from(model, attribute_name => '')
 
@@ -1291,7 +1253,7 @@ long as it is not blank, but this could not be proved.
       user_model = define_model 'User'
       favorite_columns = {
         favoriteable_id: { type: :integer, options: { null: false } },
-        favoriteable_type: { type: :string, options: { null: false } }
+        favoriteable_type: { type: :string, options: { null: false } },
       }
       favorite_model = define_model 'Favorite', favorite_columns do
         if respond_to?(:attr_accessible)
@@ -1312,6 +1274,36 @@ long as it is not blank, but this could not be proved.
         scoped_to(:favoriteable_type)
     end
 
+    context 'when polymorphic model is used on a STI model' do
+      it 'still works' do
+        columns = {
+          attachable_id: { type: :integer, options: { null: false } },
+          attachable_type: { type: :string, options: { null: false } },
+          title: { type: :string, options: { null: false } },
+        }
+
+        asset_model = define_model 'Asset', columns do
+          belongs_to :attachable, polymorphic: true
+
+          validates_uniqueness_of :title, scope: [:attachable_id, :attachable_type]
+
+          def attachable_type=(class_name)
+            super(class_name.constantize.base_class.to_s)
+          end
+        end
+
+        post_model = define_model 'Post', {} do
+          has_many :assets, as: :attachable, dependent: :destroy
+        end
+
+        guest_post_model = define_model 'GuestPost', {}, parent_class: post_model, table_name: 'posts'
+
+        asset = asset_model.create!(attachable: guest_post_model.create!, title: 'foo')
+
+        expect(asset).to validate_uniqueness_of(:title).scoped_to(:attachable_id, :attachable_type)
+      end
+    end
+
     context 'if the model the *_type column refers to is namespaced, and shares the last part of its name with an existing model' do
       it 'still works' do
         define_class 'User'
@@ -1319,7 +1311,7 @@ long as it is not blank, but this could not be proved.
         user_model = define_model 'Models::User'
         favorite_columns = {
           favoriteable_id: { type: :integer, options: { null: false } },
-          favoriteable_type: { type: :string, options: { null: false } }
+          favoriteable_type: { type: :string, options: { null: false } },
         }
         favorite_model = define_model 'Models::Favorite', favorite_columns do
           if respond_to?(:attr_accessible)
@@ -1340,6 +1332,34 @@ long as it is not blank, but this could not be proved.
           scoped_to(:favoriteable_type)
       end
     end
+
+    context 'if the model *_type column refers to an STI class' do
+      it 'still works' do
+        animal_columns = {
+          type: { type: :string, options: { null: false } },
+        }
+        animal_model = define_model 'Animal', animal_columns do
+          has_many :classifications, as: :classifiable
+        end
+        bird_model = define_model 'Bird', animal_columns, parent_class: animal_model, table_name: 'animals'
+
+        classification_columns = {
+          classifiable_id: { type: :integer },
+          classifiable_type: { type: :string },
+        }
+        classification_model = define_model 'Classification', classification_columns do
+          belongs_to :classifiable, polymorphic: true
+          validates :classifiable_id, uniqueness: { scope: :classifiable_type }
+        end
+
+        bird = bird_model.create!
+        classification = classification_model.new(classifiable: bird)
+
+        expect(classification).
+          to validate_uniqueness_of(:classifiable_id).
+          scoped_to(:classifiable_type)
+      end
+    end
   end
 
   context 'when the model does not have the attribute being tested' do
@@ -1365,7 +1385,7 @@ this could not be proved.
       context 'and the matcher is ensuring that the validation is case-sensitive' do
         it 'rejects with an appropriate failure message' do
           model = define_model_validating_uniqueness(
-            attribute_name: :name
+            attribute_name: :name,
           )
 
           model.class_eval do
@@ -1407,7 +1427,7 @@ this could not be proved.
       context 'and the matcher is ignoring case sensitivity' do
         it 'accepts (and not raise an error)' do
           model = define_model_validating_uniqueness(
-            attribute_name: :name
+            attribute_name: :name,
           )
 
           model.class_eval do
@@ -1474,20 +1494,58 @@ this could not be proved.
       record = build_record_validating_uniqueness(attribute_type: :boolean)
       running_validation = -> { expect(record).to validate_uniqueness }
       message =
-        'You attempted to assign a value which is not explicitly `true` or ' +
-        '`false`'
-
+        'You attempted to assign a value which is not explicitly `true` or `false`'
       expect(&running_validation).not_to print_warning_including(message)
     end
   end
 
+  context 'when the validation is used with alternatives' do
+    it 'accepts a single alternative value' do
+      model = define_model_validating_uniqueness(attribute_type: :string)
+      create_record_from(model, attr: 'existing value')
+
+      expect(model.new).to validate_uniqueness_of(:attr).alternatives('alternative value')
+    end
+
+    it 'accepts an array of alternative values' do
+      model = define_model_validating_uniqueness(attribute_type: :string)
+      create_record_from(model, attr: 'existing value')
+
+      expect(model.new).to validate_uniqueness_of(:attr).alternatives(['alternative1', 'alternative2'])
+    end
+
+    it 'uses the alternative value instead of calling next on the existing value' do
+      model = define_model_validating_uniqueness(attribute_type: :string)
+      create_record_from(model, attr: 'existing value')
+
+      # Create a model that would fail if .next is called on the attribute value
+      # because the next value already exists in the database
+      create_record_from(model, attr: 'existing valuef') # This is what 'existing value'.next would be
+
+      # This should pass because the alternative value is used instead of calling .next
+      expect(model.new).to validate_uniqueness_of(:attr).alternatives('alternative value')
+    end
+  end
+
+  describe '#alternatives' do
+    it 'sets the alternatives option' do
+      matcher = validate_uniqueness_of(:attr).alternatives('alternative value')
+      expect(matcher.instance_variable_get(:@options)[:alternatives]).to eq('alternative value')
+    end
+
+    it 'returns self to allow chaining' do
+      matcher = validate_uniqueness_of(:attr)
+      expect(matcher.alternatives('alternative value')).to eq(matcher)
+    end
+  end
+
   let(:model_attributes) { {} }
 
   def default_attribute
     {
       value_type: :string,
       column_type: :string,
-      options: { array: false, null: true }
+      options: { array: false, null: true },
     }
   end
 
@@ -1516,7 +1574,7 @@ this could not be proved.
     attributes.inject({}) do |options, attribute|
       options[attribute[:name]] = {
         type: attribute[:column_type],
-        options: attribute.fetch(:options, {})
+        options: attribute.fetch(:options, {}),
       }
       options
     end
@@ -1530,7 +1588,7 @@ this could not be proved.
         else
           dummy_value_for(
             attribute[:value_type],
-            array: attribute[:options][:array]
+            array: attribute[:options][:array],
           )
         end
       end
@@ -1538,37 +1596,12 @@ this could not be proved.
   end
 
   def dummy_value_for(attribute_type, array: false)
-    if array
-      [ dummy_scalar_value_for(attribute_type) ]
-    else
-      dummy_scalar_value_for(attribute_type)
-    end
-  end
-
-  def dummy_scalar_value_for(attribute_type)
-    case attribute_type
-    when :string, :text
-      'dummy value'
-    when :integer
-      1
-    when :date
-      Date.today
-    when :datetime
-      Date.today.to_datetime
-    when :time
-      Time.now
-    when :uuid
-      SecureRandom.uuid
-    when :boolean
-      true
-    else
-      raise ArgumentError, "Unknown type '#{attribute_type}'"
-    end
+    Shoulda::Matchers::Util.dummy_value_for(attribute_type, array:)
   end
 
   def next_version_of(value, value_type)
     if value.is_a?(Array)
-      [ next_version_of(value[0], value_type) ]
+      [next_version_of(value[0], value_type)]
     elsif value_type == :uuid
       SecureRandom.uuid
     elsif value.is_a?(Time)
@@ -1582,13 +1615,11 @@ this could not be proved.
 
   def build_record_from(model, extra_attributes = {})
     attributes = attributes_with_values_for(model)
-    model.new(attributes.merge(extra_attributes))
+    model.new(attributes.merge!(extra_attributes))
   end
 
   def create_record_from(model, extra_attributes = {})
-    build_record_from(model, extra_attributes).tap do |record|
-      record.save!
-    end
+    build_record_from(model, extra_attributes).tap(&:save!)
   end
 
   def define_model_validating_uniqueness(options = {}, &block)
@@ -1599,7 +1630,7 @@ this could not be proved.
       name: attribute_name,
       value_type: attribute_type,
       column_type: attribute_type,
-      options: attribute_options
+      options: attribute_options,
     )
 
     if options.key?(:attribute_value)
@@ -1609,7 +1640,7 @@ this could not be proved.
     scope_attributes = normalize_attributes(options.fetch(:scopes, []))
     scope_attribute_names = scope_attributes.map { |attr| attr[:name] }
     additional_attributes = normalize_attributes(
-      options.fetch(:additional_attributes, [])
+      options.fetch(:additional_attributes, []),
     )
     attributes = [attribute] + scope_attributes + additional_attributes
     validation_options = options.fetch(:validation_options, {})
@@ -1617,15 +1648,13 @@ this could not be proved.
 
     model = define_model(:example, column_options) do |m|
       m.validates_uniqueness_of attribute_name,
-        validation_options.merge(scope: scope_attribute_names)
+        validation_options.merge!(scope: scope_attribute_names)
 
       if m.respond_to?(:attr_accessible)
-        attributes.each do |attr|
-          m.attr_accessible(attr[:name])
-        end
+        attributes.each { |attr| m.attr_accessible(attr[:name]) }
       end
 
-      block.call(m) if block
+      block&.call(m)
     end
 
     model_attributes[model] = attributes
@@ -1641,9 +1670,7 @@ this could not be proved.
     :build_record_validating_uniqueness
 
   def create_record_validating_uniqueness(options = {}, &block)
-    build_record_validating_uniqueness(options, &block).tap do |record|
-      record.save!
-    end
+    build_record_validating_uniqueness(options, &block).tap(&:save!)
   end
   alias_method :existing_record_validating_uniqueness,
     :create_record_validating_uniqueness
@@ -1652,13 +1679,17 @@ this could not be proved.
     options = options.dup
     enum_scope_attribute =
       normalize_attribute(options.delete(:enum_scope)).
-      merge(value_type: :integer, column_type: :integer)
+        merge(value_type: :integer, column_type: :integer)
     additional_scopes = options.delete(:additional_scopes) { [] }
     options[:scopes] = [enum_scope_attribute] + additional_scopes
     dummy_enum_values = [:foo, :bar]
 
     model = define_model_validating_uniqueness(options)
-    model.enum(enum_scope_attribute[:name] => dummy_enum_values)
+    if rails_gt_8_0?
+      model.enum enum_scope_attribute[:name], dummy_enum_values
+    else
+      model.enum(enum_scope_attribute[:name] => dummy_enum_values)
+    end
 
     build_record_from(model)
   end
@@ -1682,7 +1713,7 @@ this could not be proved.
   def validation_matcher_scenario_args
     super.deep_merge(
       matcher_name: :validate_uniqueness_of,
-      model_creator: :"active_record/uniqueness_matcher"
+      model_creator: :"active_record/uniqueness_matcher",
     )
   end
 end
