@@ -27,7 +27,12 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
         it 'states that it should delegate method to the right object with right argument' do
           matcher = delegate_method(:method_name).to(:delegate).
             with_arguments(:foo, bar: [1, 2])
-          message = 'delegate #method_name to the #delegate object passing arguments [:foo, {:bar=>[1, 2]}]'
+
+          message = if ruby_gt_3_4?
+                      'delegate #method_name to the #delegate object passing arguments [:foo, {bar: [1, 2]}]'
+                    else
+                      'delegate #method_name to the #delegate object passing arguments [:foo, {:bar=>[1, 2]}]'
+                    end
 
           expect(matcher.description).to eq message
         end
@@ -102,6 +107,15 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
           end
         end
       end
+
+      context 'qualified with #with_private' do
+        it 'states that it should delegate method to the right object with right argument and makes is private' do
+          matcher = delegate_method(:method_name).to(:delegate).with_private
+          message = 'delegate #method_name to the #delegate object privately'
+
+          expect(matcher.description).to eq message
+        end
+      end
     end
 
     context 'when the subject is a class' do
@@ -129,7 +143,11 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
         it 'states that it should delegate method to the right object with right argument' do
           matcher = delegate_method(:method_name).to(:delegate).
             with_arguments(:foo, bar: [1, 2])
-          message = 'delegate .method_name to the .delegate object passing arguments [:foo, {:bar=>[1, 2]}]'
+          message = if ruby_gt_3_4?
+                      'delegate .method_name to the .delegate object passing arguments [:foo, {bar: [1, 2]}]'
+                    else
+                      'delegate .method_name to the .delegate object passing arguments [:foo, {:bar=>[1, 2]}]'
+                    end
 
           expect(matcher.description).to eq message
         end
@@ -180,7 +198,7 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
         message = [
           'Expected PostOffice to delegate #deliver_mail to the #mailman object.',
           '',
-          'Method calls sent to PostOffice#mailman: (none)'
+          'Method calls sent to PostOffice#mailman: (none)',
         ].join("\n")
 
         expect {
@@ -194,7 +212,7 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
         message = [
           'Expected PostOffice to delegate .deliver_mail to the .mailman object.',
           '',
-          'Method calls sent to PostOffice.mailman: (none)'
+          'Method calls sent to PostOffice.mailman: (none)',
         ].join("\n")
 
         expect {
@@ -264,7 +282,7 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
       define_class('Mailman')
 
       define_class('PostOffice') do
-        def deliver_mail(*args)
+        def deliver_mail(*)
           mailman.deliver_mail('221B Baker St.', hastily: true)
         end
 
@@ -285,7 +303,8 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
         context 'negating the matcher' do
           it 'rejects with the correct failure message' do
             post_office = PostOffice.new
-            message = 'Expected PostOffice not to delegate #deliver_mail to the #mailman object passing arguments ["221B Baker St.", {:hastily=>true}], but it did.'
+            hash_message = ruby_gt_3_4? ? '{hastily: true}' : '{:hastily=>true}'
+            message = "Expected PostOffice not to delegate #deliver_mail to the #mailman object passing arguments [\"221B Baker St.\", #{hash_message}], but it did."
 
             expect {
               expect(post_office).
@@ -300,13 +319,14 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
       context 'when not given the correct arguments' do
         it 'rejects with the correct failure message' do
           post_office = PostOffice.new
+          hash_message = ruby_gt_3_4? ? 'deliver_mail("221B Baker St.", {hastily: true})' : 'deliver_mail("221B Baker St.", {:hastily=>true})'
           message = [
             'Expected PostOffice to delegate #deliver_mail to the #mailman object',
             'passing arguments ["123 Nowhere Ln."].',
             '',
             'Method calls sent to PostOffice#mailman:',
             '',
-            '1) deliver_mail("221B Baker St.", {:hastily=>true})'
+            "1) #{hash_message}",
           ].join("\n")
 
           expect {
@@ -364,7 +384,7 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
           '',
           'Method calls sent to PostOffice#mailman:',
           '',
-          '1) deliver_mail_and_avoid_dogs()'
+          '1) deliver_mail_and_avoid_dogs()',
         ].join("\n")
 
         expect {
@@ -394,7 +414,7 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
           end
 
           person = Person.new
-          expect(person).to delegate_method(:hello). to(:country).with_prefix
+          expect(person).to delegate_method(:hello).to(:country).with_prefix
         end
       end
 
@@ -412,13 +432,13 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
             'Expected Person to delegate #country_hello to the #country object as',
             '#hello.',
             '',
-            'Method calls sent to Person#country: (none)'
+            'Method calls sent to Person#country: (none)',
           ].join("\n")
 
           person = Person.new
 
           expect {
-            expect(person).to delegate_method(:hello). to(:country).with_prefix
+            expect(person).to delegate_method(:hello).to(:country).with_prefix
           }.to fail_with_message(message)
         end
       end
@@ -462,7 +482,7 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
             'Expected Person to delegate #country_hello to the #country object as',
             '#hello.',
             '',
-            'Method calls sent to Person#country: (none)'
+            'Method calls sent to Person#country: (none)',
           ].join("\n")
 
           person = Person.new
@@ -514,7 +534,7 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
             'Expected Person to delegate #county_hello to the #country object as',
             '#hello.',
             '',
-            'Method calls sent to Person#country: (none)'
+            'Method calls sent to Person#country: (none)',
           ].join("\n")
 
           person = Person.new
@@ -535,7 +555,8 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
         it 'accepts' do
           define_class('Person') do
             delegate :hello, to: :country, allow_nil: true
-            def country; end
+            def country
+            end
           end
 
           person = Person.new
@@ -548,7 +569,8 @@ describe Shoulda::Matchers::Independent::DelegateMethodMatcher do
         it 'rejects with the correct failure message' do
           define_class('Person') do
             delegate :hello, to: :country
-            def country; end
+            def country
+            end
           end
 
           person = Person.new
@@ -578,7 +600,8 @@ to account for when #country *was* nil.
 
             def_delegators :country, :hello
 
-            def country; end
+            def country
+            end
           end
 
           person = Person.new
@@ -592,7 +615,9 @@ to account for when #country *was* nil.
           MESSAGE
 
           expectation = lambda do
-            expect(person).to delegate_method(:hello).to(:country).allow_nil
+            silence_warnings do
+              expect(person).to delegate_method(:hello).to(:country).allow_nil
+            end
           end
 
           expect(&expectation).to fail_with_message(message)
@@ -604,10 +629,12 @@ to account for when #country *was* nil.
       context 'when the delegating method accounts for the delegate object being nil' do
         it 'accepts' do
           define_class('Person') do
-            def country; end
+            def country
+            end
 
             def hello
               return unless country
+
               country.hello
             end
           end
@@ -621,7 +648,8 @@ to account for when #country *was* nil.
       context 'when the delegating method does not account for the delegate object being nil' do
         it 'rejects with the correct failure message' do
           define_class('Person') do
-            def country; end
+            def country
+            end
 
             def hello
               country.hello
@@ -647,4 +675,116 @@ to account for when #country *was* nil.
       end
     end
   end
+
+  context 'qualified with #with_private' do
+    context 'when using delegate from Rails' do
+      context 'when delegations were defined with :private' do
+        it 'accepts' do
+          define_class('Person') do
+            delegate :hello, to: :country, private: true
+            def country
+            end
+          end
+
+          person = Person.new
+
+          expect(person).to delegate_method(:hello).to(:country).with_private
+        end
+      end
+
+      context 'when delegations were not defined with :private' do
+        it 'rejects with the correct failure message' do
+          define_class('Person') do
+            delegate :hello, to: :country
+            def country
+            end
+          end
+
+          person = Person.new
+
+          message = <<-MESSAGE
+Expected Person to delegate #hello to the #country object privately.
+
+Person#hello did delegate to #country, but 'private: true' is missing.
+          MESSAGE
+
+          expectation = lambda do
+            expect(person).to delegate_method(:hello).to(:country).with_private
+          end
+
+          expect(&expectation).to fail_with_message(message)
+        end
+
+        context 'with :prefix' do
+          it 'accepts' do
+            define_class('Person') do
+              delegate :hello, to: :country, private: true, prefix: :user
+              def country
+              end
+            end
+
+            person = Person.new
+
+            expect(person).to delegate_method(:hello).to(:country).with_prefix(:user).with_private
+          end
+        end
+
+        context 'with :as' do
+          it 'accepts' do
+            define_class('Company') do
+              def name
+                'Acme Company'
+              end
+            end
+
+            define_class('Person') do
+              private
+
+              def company_name
+                company.name
+              end
+
+              def company
+                Company.new
+              end
+            end
+
+            person = Person.new
+            matcher = delegate_method(:company_name).to(:company).as(:name).with_private
+            matcher.matches?(person)
+
+            expect(person.send(:company).name).to eq 'Acme Company'
+          end
+
+          context 'and :prefix' do
+            it 'accepts' do
+              define_class('Company') do
+                def name
+                  'Acme Company'
+                end
+              end
+
+              define_class('Person') do
+                private
+
+                def company_name
+                  company.name
+                end
+
+                def company
+                  Company.new
+                end
+              end
+
+              person = Person.new
+              matcher = delegate_method(:company_name).to(:company).with_prefix(:user).as(:name).with_private
+              matcher.matches?(person)
+
+              expect(person.send(:company).name).to eq 'Acme Company'
+            end
+          end
+        end
+      end
+    end
+  end
 end
